@@ -33,7 +33,13 @@ import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.Tree;
 
 import com.clustercontrol.action.FacilityTree;
+import com.clustercontrol.action.OwnerRoleFacilityTree;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.util.FacilityTreeItemUtil;
+import com.clustercontrol.viewer.CommonTableViewer;
+import com.clustercontrol.viewer.FacilityTreeContentProvider;
+import com.clustercontrol.viewer.FacilityTreeLabelProvider;
+import com.clustercontrol.viewer.FacilityTreeViewerSorter;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -53,54 +59,65 @@ public class FacilityTreeComposite extends Composite {
 	private CommonTableViewer tableViewer = null;
 
 	/** ツリービューア */
+	//ノードマップオプションで使用するためprotected
 	protected TreeViewer treeViewer = null;
 
 	/** rootFacilityId以下のスコープ情報を取得する。 */
-	protected String rootFacilityId = null;
+	private String rootFacilityId = null;
 
 	/** tableViewer登録Item */
-	protected FacilityTreeItem treeItem = null;
+	private FacilityTreeItem treeItem = null;
 
 	/** 選択アイテム */
+	//ノードマップオプションで使用するためprotected
 	protected FacilityTreeItem selectItem = null;
 
 	/** 選択アイテム数 */
+	//ノードマップオプションで使用するためprotected
 	protected int subScopeNumber;
 
 	/**ノードをツリーに含めるか？ */
-	protected boolean scopeOnly = false;
+	private boolean scopeOnly = false;
 
 	/**選択対象はノードだけか？ */
 	boolean selectNodeOnly = false;
 
 	/**未登録ノード　スコープをツリーに含めるか？**/
-	protected boolean unregistered = true;
+	private boolean unregistered = true;
 
 	/**内部イベント　スコープをツリーに含めるか？**/
-	protected boolean internal = true;
+	private boolean internal = true;
 
 	/** リポジトリ情報更新により、表示をリフレッシュするかどうか **/
+	//ノードマップオプションで使用するためprotected
 	protected boolean topicRefresh = true;
 
 	/** リポジトリ情報のキャッシュを保持・管理するオブジェクト */
+	//ノードマップオプションで使用するためprotected
 	protected FacilityTree facilityTree = null;
 
+	/** オーナーロールID */
+	private String ownerRoleId = null;
+
 	/** parent Composite */
-	protected Composite parent = null;
+	private Composite parent = null;
 
 	// ----- コンストラクタ ----- //
 
-	public FacilityTreeComposite(Composite parent, int style) {
+	public FacilityTreeComposite(Composite parent, int style, String ownerRoleId) {
 		super(parent, style);
 
 		this.scopeOnly = false;
 		this.unregistered = true;
 		this.internal = true;
 		this.parent = parent;
+		this.ownerRoleId = ownerRoleId;
 		this.createContents();
 	}
 
-	public FacilityTreeComposite(Composite parent, int style, boolean selectNodeOnly) {
+	public FacilityTreeComposite(Composite parent, int style,
+			String ownerRoleId,
+			boolean selectNodeOnly) {
 		super(parent, style);
 
 		this.selectNodeOnly = selectNodeOnly;
@@ -108,10 +125,12 @@ public class FacilityTreeComposite extends Composite {
 		this.unregistered = false;
 		this.internal = false;
 		this.parent = parent;
+		this.ownerRoleId = ownerRoleId;
 		this.createContents();
 	}
 
 	public FacilityTreeComposite(Composite parent, int style,
+			String ownerRoleId,
 			boolean scopeOnly ,
 			boolean unregistered,
 			boolean internal) {
@@ -121,10 +140,24 @@ public class FacilityTreeComposite extends Composite {
 		this.unregistered = unregistered;
 		this.internal = internal;
 		this.parent = parent;
+		this.ownerRoleId = ownerRoleId;
 		this.createContents();
 	}
 
+	/**
+	 * 特定のスコープ配下のみを表示するコンストラクタ<br>
+	 * （ver 4.1.0 現在、VM管理のみから呼び出されているコンストラクタ）
+	 * 
+	 * @param parent 親のコンポジット
+	 * @param style スタイル
+	 * @param ownerRoleId オーナーロールID
+	 * @param scopeOnly スコープのみのスコープツリーとするかどうか
+	 * @param unregistered UNREGISTEREDをスコープツリーに含めるかどうか
+	 * @param internal INTERNALをスコープツリーに含めるかどうか
+	 * @param rootFacilityId ツリーのルートとするファシリティID
+	 */
 	public FacilityTreeComposite(Composite parent, int style,
+			String ownerRoleId,
 			boolean scopeOnly ,
 			boolean unregistered,
 			boolean internal,
@@ -136,20 +169,23 @@ public class FacilityTreeComposite extends Composite {
 		this.internal = internal;
 		this.rootFacilityId = rootFacilityId;
 		this.parent = parent;
+		this.ownerRoleId = ownerRoleId;
 		this.createContents();
 	}
-
+	
 	/**
 	 * コンストラクタ
 	 * 
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
+	 * @param ownerRoleId オーナーロールID
 	 * @param scopeOnly スコープのみのスコープツリーとするかどうか
 	 * @param unregistered UNREGISTEREDをスコープツリーに含めるかどうか
 	 * @param internal INTERNALをスコープツリーに含めるかどうか
 	 * @param topicRefresh リポジトリ情報が更新された際に画面リフレッシュするかどうか
 	 */
 	public FacilityTreeComposite(Composite parent, int style,
+			String ownerRoleId,
 			boolean scopeOnly ,
 			boolean unregistered,
 			boolean internal,
@@ -161,6 +197,7 @@ public class FacilityTreeComposite extends Composite {
 		this.internal = internal;
 		this.topicRefresh = topicRefresh;
 		this.parent = parent;
+		this.ownerRoleId = ownerRoleId;
 		this.createContents();
 	}
 
@@ -215,6 +252,7 @@ public class FacilityTreeComposite extends Composite {
 	/**
 	 * コンポジットを生成します。
 	 */
+	//ノードマップオプションで使用するためprotected
 	protected void createContents() {
 
 		// コンポジットのレイアウト定義
@@ -248,10 +286,10 @@ public class FacilityTreeComposite extends Composite {
 			@Override
 			public void selectionChanged(SelectionChangedEvent event) {
 				StructuredSelection selection = (StructuredSelection) event
-				.getSelection();
+						.getSelection();
 
 				selectItem = (FacilityTreeItem) selection
-				.getFirstElement();
+						.getFirstElement();
 
 				if (selectItem instanceof FacilityTreeItem) {
 					subScopeNumber = selectItem.getChildren().size();
@@ -261,7 +299,12 @@ public class FacilityTreeComposite extends Composite {
 
 		//マネージャからのファシリティツリー更新
 		final FacilityTreeComposite composite = this;
-		facilityTree = new FacilityTree();
+		if (this.ownerRoleId != null) {
+			// オーナーロールIDでの抽出
+			facilityTree = new OwnerRoleFacilityTree(this.ownerRoleId, this.selectNodeOnly);
+		} else {
+			facilityTree = new FacilityTree();
+		}
 		if (topicRefresh) {
 			facilityTree.addComposite(composite);
 		}
@@ -284,7 +327,13 @@ public class FacilityTreeComposite extends Composite {
 	public void update() {
 
 		// 外部契機でファシリティツリーが更新された場合に、自分の画面もリフレッシュ
-		treeItem = facilityTree.getTreeItem();
+		if (selectNodeOnly) {
+			//　ノードのみ取得する場合
+			treeItem = facilityTree.getTreeItem();
+		} else {
+			//　上記以外
+			treeItem = facilityTree.getTreeItem();
+		}
 
 		//if(treeItem != null)
 		//	m_log.debug("treeItem is not null");
@@ -297,20 +346,14 @@ public class FacilityTreeComposite extends Composite {
 			FacilityTreeItem scope = (treeItem.getChildren()).get(0);
 
 			//ファシリティツリーから特定のスコープを取り外す。
-			//FIXME ここでは組込みスコープがFacilityIDで決めうちになっている。
-			//後々は直したい。
-
-			String Internal     = "INTERNAL";
-			String Unregistered = "UNREGISTERED";
-
 			if(!internal){
-				if(FacilityTreeItemUtil.removeChild(scope, Internal)){
+				if(FacilityTreeItemUtil.removeChild(scope, FacilityTreeAttributeConstant.INTERNAL_SCOPE)){
 				}else{
 					//まずい。"INTERNAL"スコープがない！
 				}
 			}
 			if(!unregistered){
-				if(FacilityTreeItemUtil.removeChild(scope, Unregistered)){
+				if(FacilityTreeItemUtil.removeChild(scope, FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
 				}else{
 					//まずい。"UNREGISTERED"スコープがない！
 				}
@@ -322,9 +365,6 @@ public class FacilityTreeComposite extends Composite {
 			if (scopeOnly) {
 				FacilityTreeItemUtil.removeNode(scope);
 			}
-			if(selectNodeOnly){
-				FacilityTreeItemUtil.removeScope(scope);
-			}
 
 			// SWTアクセスを許可するスレッドからの操作用
 			checkAsyncExec(new Runnable(){
