@@ -56,7 +56,7 @@ public abstract class AutoUpdateView extends CommonViewPart {
 	 * @param autoReloaded
 	 *            自動更新中である場合、true
 	 */
-	protected void setAutoReloaded(boolean autoReloaded) {
+	private void setAutoReloaded(boolean autoReloaded) {
 		this.autoReloaded = autoReloaded;
 	}
 
