@@ -18,6 +18,7 @@
  */
 package org.vafada.swtcalendar;
 
+import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Locale;
 
@@ -33,6 +34,8 @@ import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 
+import com.clustercontrol.ws.calendar.Ymd;
+
 public class SWTCalendar extends Composite {
 	/**
 	 * Style constant for making Sundays red.
@@ -169,6 +172,17 @@ public class SWTCalendar extends Composite {
 		setFont(parent.getFont());
 	}
 
+	/**
+	 * 複数選択用SWTカレンダ更新
+	 * @since 4.1.0
+	 * @see com.clustercontrol.calendar.dialog.CalendarPatternDialog#customizeDialog
+	 * @param dateList
+	 */
+	public void updateCalendar(ArrayList<Ymd> dateList){
+		dayChooser.update(dateList);
+	}
+
+
 	public SWTCalendar(Composite parent) {
 		this(parent, SWT.FLAT);
 	}
