@@ -39,9 +39,9 @@ import com.clustercontrol.collectiverun.composite.action.HistorySelectionChanged
 import com.clustercontrol.collectiverun.preference.CollectiveRunPreferencePage;
 import com.clustercontrol.collectiverun.util.CollectiveRunEndpointWrapper;
 import com.clustercontrol.collectiverun.util.HistoryFilterPropertyUtil;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.collectiverun.HistoryFilterInfo;
 import com.clustercontrol.ws.collectiverun.HistoryInfo;
 import com.clustercontrol.ws.collectiverun.InvalidRole_Exception;
@@ -63,11 +63,11 @@ public class HistoryComposite extends Composite {
 
 	private CommonTableViewer m_viewer = null;
 
-	protected Label m_labelType = null;
+	private Label m_labelType = null;
 
-	protected Label m_labelCount = null;
+	private Label m_labelCount = null;
 
-	protected String m_sessionId = null;
+	private String m_sessionId = null;
 
 	/**
 	 * コンストラクタ
@@ -356,8 +356,16 @@ public class HistoryComposite extends Composite {
 				ArrayList<Object> line = new ArrayList<Object>();
 				line.add(info.getStatus());
 				line.add(info.getSessionId());
-				line.add(new Date(info.getStartDate()));
-				line.add(new Date(info.getEndDate()));
+				if (info.getStartDate() != null) {
+					line.add(new Date(info.getStartDate()));
+				} else {
+					line.add("");
+				}
+				if (info.getEndDate() != null) {
+					line.add(new Date(info.getEndDate()));
+				} else {
+					line.add("");
+				}
 				line.add(info.getType());
 				line.add(info.getName());
 				line.add(info.getFacilityId());
