@@ -38,9 +38,9 @@ import com.clustercontrol.util.Messages;
  * 
  */
 public class SetMasterDialog extends CommonDialog {
-	protected SashForm sash = null;
-	protected TreeComposite treeComposite = null;
-	protected Composite detailComposite = null;
+	private SashForm sash = null;
+	private TreeComposite treeComposite = null;
+	private Composite detailComposite = null;
 
 	/**
 	 * コンストラクタ
