@@ -85,7 +85,7 @@ public class ParameterView extends CommonViewPart {
 	 * 
 	 * 
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -110,12 +110,12 @@ public class ParameterView extends CommonViewPart {
 	 * 
 	 * @param manager
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ビューのアクションのインスタンスを取得
 		IToolBarManager toolbar = this.getViewSite().getActionBars()
-		.getToolBarManager();
+				.getToolBarManager();
 		ActionContributionItem collectiveRunAction = (ActionContributionItem) toolbar
-		.find(CollectiveRunAction.ID);
+				.find(CollectiveRunAction.ID);
 
 		//ポップアップメニューにアクションを追加
 		manager.add(collectiveRunAction.getAction());
