@@ -49,10 +49,9 @@ public class GetParameterTableDefine {
 	 * 
 	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
 	 */
-	@SuppressWarnings("unchecked")
-	public static ArrayList get() {
+	public static ArrayList<TableColumnInfo> get() {
 		//テーブル定義配列
-		ArrayList tableDefine = new ArrayList();
+		ArrayList<TableColumnInfo> tableDefine = new ArrayList<TableColumnInfo>();
 
 		tableDefine.add(PARAM_ID,
 				new TableColumnInfo(Messages.getString("name"), TableColumnInfo.NONE, 110, SWT.LEFT));
