@@ -31,10 +31,10 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
 import com.clustercontrol.accesscontrol.util.LocalSession;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.jobmanagement.action.GetForwardFileTableDefine;
 import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobForwardFile;
 
@@ -50,15 +50,15 @@ public class ForwardFileComposite extends Composite {
 	private static Log m_log = LogFactory.getLog( ForwardFileComposite.class );
 
 	/** テーブルビューアー */
-	protected CommonTableViewer m_viewer = null;
+	private CommonTableViewer m_viewer = null;
 	/** セッションID */
-	protected String m_sessionId = null;
+	private String m_sessionId = null;
 	/** 所属ジョブユニットのジョブID */
-	protected String m_jobunitId = null;
+	private String m_jobunitId = null;
 	/** ジョブID */
-	protected String m_jobId = null;
+	private String m_jobId = null;
 	/** ID用ラベル */
-	protected Label m_idLabel = null;
+	private Label m_idLabel = null;
 
 	/**
 	 * コンストラクタ
