@@ -37,7 +37,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  */
 public class JobDetailSelectionChangedListener implements ISelectionChangedListener {
 	/** ジョブ[ジョブ詳細]ビュー用のコンポジット */
-	protected DetailComposite m_composite;
+	private DetailComposite m_composite;
 
 	/**
 	 * コンストラクタ
@@ -90,13 +90,13 @@ public class JobDetailSelectionChangedListener implements ISelectionChangedListe
 
 		//アクティブページを手に入れる
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 
 		//ビューを更新する
 		IViewPart viewPart = page.findView(JobNodeDetailView.ID);
 		if (viewPart != null) {
 			JobNodeDetailView view = (JobNodeDetailView) viewPart
-			.getAdapter(JobNodeDetailView.class);
+					.getAdapter(JobNodeDetailView.class);
 			view.update(sessionId, jobunitId, jobId);
 		}
 
@@ -104,7 +104,7 @@ public class JobDetailSelectionChangedListener implements ISelectionChangedListe
 		viewPart = page.findView(ForwardFileView.ID);
 		if (viewPart != null) {
 			ForwardFileView view = (ForwardFileView) viewPart
-			.getAdapter(ForwardFileView.class);
+					.getAdapter(ForwardFileView.class);
 			view.update(sessionId, jobunitId, jobId);
 		}
 
