@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.util;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -24,24 +25,28 @@ import java.util.regex.Pattern;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.eclipse.jface.dialogs.MessageDialog;
 
 import com.clustercontrol.fault.JobInvalid;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
-import com.clustercontrol.ws.jobmanagement.JobManagementUserInfo;
+import com.clustercontrol.ws.jobmanagement.JobInvalid_Exception;
 import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
 import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
+import com.clustercontrol.ws.jobmanagement.OtherUserGetLock_Exception;
+import com.clustercontrol.ws.jobmanagement.UpdateTimeNotLatest_Exception;
 import com.clustercontrol.ws.notify.NotifyRelationInfo;
 
 /**
  * ジョブユーティリティクラス
  * 
- * 以下ィを提供します。<BR>
+ * 以下を提供します。<BR>
  * <li>ジョブツリーアイテムに関するユーティリティ
  * <li>ログインユーザが参照可能なジョブユニットかどうかをチェックするユーティリティ
  * 
@@ -50,7 +55,7 @@ import com.clustercontrol.ws.notify.NotifyRelationInfo;
  */
 public class JobUtil {
 	/** ログ出力のインスタンス<BR> */
-	protected static Log m_log = LogFactory.getLog( JobUtil.class );
+	private static Log m_log = LogFactory.getLog( JobUtil.class );
 
 	/** コピーしたジョブIDの接頭語 */
 	private static final String COPY_OF = "Copy_Of_";
@@ -65,6 +70,8 @@ public class JobUtil {
 		JobTreeItem clone = null;
 		if(original != null){
 			clone = JobTreeItemUtil.clone(original, null);
+			// 新規登録の判定のため、createTimeをクリアする
+			clone.getData().setCreateTime(null);
 		}
 
 		return clone;
@@ -75,42 +82,25 @@ public class JobUtil {
 	 * @param top コピー元ジョブツリーアイテム
 	 * @return コピーとして作成されたジョブツリーアイテム
 	 */
-	public static JobTreeItem copy(JobTreeItem original, JobTreeItem top, String jobunitId) {
+	public static JobTreeItem copy(JobTreeItem original, JobTreeItem top, String jobunitId, String ownerRoleId) {
 		JobTreeItem clone = copy(original);
 		clone.getData().setJobunitId(jobunitId);
+		clone.getData().setOwnerRoleId(ownerRoleId);
 
-		//待ち条件を削除する
-		deleteWaitRule(clone);
-
+		//オーナーロールIDをコピー先のものに変更
+		clone = changeOwnerRoleId(clone, ownerRoleId);
+		
 		//ジョブIDの変更
-		changeJobId(clone, top, clone);
+		HashMap<String, String> jobIdMap = changeJobId(clone, top, clone);
 
-		//変更有無フラグの変更
-		setEditFlg(clone);
+		//待ち条件を変更する
+		modifyWaitRule(clone, jobIdMap);
 
 		//FIXME ジョブユニットIDを変更する
 
 		return clone;
 	}
 
-	/**
-	 * 所属しているジョブユニットのeditフラグをtrueに変更する。
-	 */
-	public static void setEditFlg(JobTreeItem item) {
-		JobInfo info = item.getData();
-		if (info.getType() == JobConstant.TYPE_JOBUNIT) {
-			m_log.debug("info.isEdit " + info.isEdit() + " -> true");
-			info.setEdit(true);
-		} else {
-			JobTreeItem parent = item.getParent();
-			if (parent == null) {
-				m_log.warn("setEditFlg() error, parent == null");
-			} else {
-				setEditFlg(item.getParent());
-			}
-		}
-	}
-
 	/**
 	 * 例1：COPY_OF_(13)_job0001をjob0001に変換させる。
 	 * 例2：COPY_OF_job0001をjob0001に変換させる。
@@ -133,6 +123,23 @@ public class JobUtil {
 		// マッチしなかったら、そのまま返す。
 		return jobId;
 	}
+	
+	/**
+	 * オーナーロールIDを一括変更する<BR>
+	 * ジョブツリーアイテムのツリー階層の全てに対して一括変更する。<BR>
+	 * @param clone
+	 * @param ownerRoleId
+	 * @return
+	 */
+	private static JobTreeItem changeOwnerRoleId(JobTreeItem clone, String ownerRoleId){
+		//子JobTreeItemを取得
+		List<JobTreeItem> childrens = clone.getChildren();
+		for (JobTreeItem children : new ArrayList<JobTreeItem>(childrens)) {
+			children.getData().setOwnerRoleId(ownerRoleId);
+			children = changeOwnerRoleId(children,ownerRoleId);
+		}
+		return clone;
+	}
 
 	/**
 	 * ジョブIDを一括変更する<BR>
@@ -144,9 +151,11 @@ public class JobUtil {
 	 * @param top ジョブIDの重複チェック対象のジョブツリーアイテム
 	 * @param clone ジョブIDの重複チェック対象のジョブツリーアイテム
 	 */
-	private static void changeJobId(JobTreeItem item, JobTreeItem top, JobTreeItem clone) {
+	private static HashMap<String, String> changeJobId(JobTreeItem item, JobTreeItem top, JobTreeItem clone) {
 		if(item == null || top == null)
-			return;
+			return null;
+
+		HashMap<String, String> jobIdMap = new HashMap<String, String>();
 
 		//ジョブIDを変更
 		JobInfo info = item.getData();
@@ -173,7 +182,11 @@ public class JobUtil {
 					break;
 				}
 			}
-			info.setId(jobId.toString());
+			//コピー前後のジョブIDの対応を記録
+			//key:コピー前のジョブID、value:コピー後のジョブID
+			jobIdMap.put(info.getId(), jobId);
+
+			info.setId(jobId);
 
 			// ジョブユニットの場合のみジョブユニットIDを上書き
 			if (info.getType() == JobConstant.TYPE_JOBUNIT) {
@@ -239,33 +252,49 @@ public class JobUtil {
 		for(int i = 0; i < childrens.size(); i++){
 			childrens.get(i).getData().setJobunitId(info.getJobunitId());
 			//m_log.debug("changeJobId() set childrens[i] " + info.getJobunitId());
-			changeJobId(childrens.get(i), top, clone);
+			jobIdMap.putAll(changeJobId(childrens.get(i), top, clone));
 		}
+
+		return jobIdMap;
 	}
 
+
 	/**
-	 * ジョブツリーアイテムからジョブ待ち条件情報を削除する<BR>
-	 * ジョブツリーアイテムのツリー階層の全てが削除対象
+	 * ジョブツリーアイテムのジョブ待ち条件情報を修正する<BR>
+	 * ジョブツリーアイテムのツリー階層の全てが修正対象
 	 * 
-	 * @param item ジョブ待ち条件情報を削除するジョブツリーアイテム
+	 * @param item ジョブ待ち条件情報を修正するジョブツリーアイテム
 	 */
-	private static void deleteWaitRule(JobTreeItem item) {
+	private static void modifyWaitRule(JobTreeItem item, HashMap<String, String>jobIdMap) {
 		if(item == null)
 			return;
 
 		JobInfo info = item.getData();
 		if(info != null){
-			//待ち条件を削除する
+			//待ち条件となるジョブがコピー元に存在する場合には、コピー先のジョブIDに修正する
+			//存在しない場合には、削除する
+			//時刻待ち条件の場合には、そのままコピー先にコピーする
 			JobWaitRuleInfo waitRule = info.getWaitRule();
 			if(waitRule != null && waitRule.getObject() != null){
+				ArrayList<JobObjectInfo> list = new ArrayList<JobObjectInfo>();
+				for (JobObjectInfo jobObjectInfo : waitRule.getObject()) {
+					String jobId = jobIdMap.get(jobObjectInfo.getJobId());
+					if (jobId != null) {
+						jobObjectInfo.setJobId(jobId);
+						list.add(jobObjectInfo);
+					} else if (jobObjectInfo.getTime() != null) {
+						list.add(jobObjectInfo);
+					}
+				}
 				waitRule.getObject().clear();
+				waitRule.getObject().addAll(list);
 			}
 		}
 
 		//子JobTreeItemを取得
 		List<JobTreeItem> childrens = item.getChildren();
 		for(int i = 0; i < childrens.size(); i++){
-			deleteWaitRule(childrens.get(i));
+			modifyWaitRule(childrens.get(i), jobIdMap);
 		}
 	}
 
@@ -491,27 +520,68 @@ public class JobUtil {
 	}
 
 	/**
-	 * ログインユーザで参照可能なジョブユニットかどうかチェックします。<BR>
-	 * @param jobunit 選択されたジョブユニット
-	 * @param loginUser ログインユーザのユーザID
-	 * @return ログインユーザで参照可能なジョブユニットである場合true
+	 * 編集ロックを取得します。
+	 * @param jobunitId
+	 * @param updateTime
+	 * @param forceFlag
+	 * @return
+	 * @throws OtherUserGetLock_Exception
 	 */
-	public static boolean isReferableJobunit (JobTreeItem jobunit, String loginUser) {
+	public static Integer getEditLock(String jobunitId, Long updateTime, boolean forceFlag) throws OtherUserGetLock_Exception {
+		try {
+			return JobEndpointWrapper.getEditLock(jobunitId, updateTime, forceFlag);
+		} catch (OtherUserGetLock_Exception e) {
+			throw e;
+		} catch (InvalidRole_Exception e) {
+			MessageDialog.openInformation(null, Messages.getString("message"),
+					Messages.getString("message.accesscontrol.16"));
+		} catch (UpdateTimeNotLatest_Exception e) {
+			// 保持しているジョブツリーが最新でない
+			MessageDialog.openInformation(null, Messages.getString("message"),
+					e.getMessage());
+		} catch (JobInvalid_Exception e) {
+			MessageDialog.openInformation(null, Messages.getString("message"),
+					e.getMessage());
+		} catch (Exception e) {
+			m_log.warn("run(), " + e.getMessage(), e);
+			MessageDialog.openError(
+					null,
+					Messages.getString("failed"),
+					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
+		return null;
+	}
 
-		boolean ret = false;
-
-		List<JobManagementUserInfo> userInfo = jobunit.getData().getManagementUser();
-		if (userInfo == null || userInfo.size() == 0) {
-			ret = true;
-		} else {
-			for (JobManagementUserInfo i : userInfo) {
-				if (loginUser.equals(i.getUserId())) {
-					ret = true;
-					break;
-				}
-			}
+	/**
+	 * ジョブユニットIDをすべて更新する。<BR>
+	 * 
+	 * @param item ジョブツリーアイテム
+	 * @param jobunitID ジョブユニットID
+	 */
+	public static void setJobunitIdAll(JobTreeItem item, String jobunitId) {
+		if (item == null || item.getData() == null) {
+			return;
 		}
 
-		return ret;
+		if (item.getData().getType() == JobConstant.TYPE_JOBUNIT) {
+			jobunitId = item.getData().getJobunitId();
+		}
+
+		m_log.trace("setJobunitIdAll() : jobId = " + item.getData().getId() +
+				", old jobunitId = " + item.getData().getJobunitId() +
+				", new jobunitId = " + jobunitId);
+
+		// ジョブユニットIDを変更する
+		item.getData().setJobunitId(jobunitId);
+
+		// 参照ジョブの場合は参照先のジョブユニットIDを変更する
+		if (item.getData().getType() == JobConstant.TYPE_REFERJOB) {
+			item.getData().setReferJobUnitId(jobunitId);
+		}
+
+		// 子のジョブツリーアイテムを再帰的に呼び出す
+		for (JobTreeItem child : item.getChildren()) {
+			setJobunitIdAll(child, jobunitId);
+		}
 	}
 }
\ No newline at end of file
