@@ -15,6 +15,11 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.view;
 
+import java.util.ArrayList;
+import java.util.List;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.action.ActionContributionItem;
 import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
@@ -29,44 +34,50 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
 
+import com.clustercontrol.accesscontrol.util.ObjectBean;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.JobListComposite;
 import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
 import com.clustercontrol.jobmanagement.composite.action.JobListSelectionChangedListener;
 import com.clustercontrol.jobmanagement.composite.action.JobTreeSelectionChangedListener;
-import com.clustercontrol.jobmanagement.util.JobUtil;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.view.action.CopyJobAction;
 import com.clustercontrol.jobmanagement.view.action.CreateFileJobAction;
 import com.clustercontrol.jobmanagement.view.action.CreateJobAction;
 import com.clustercontrol.jobmanagement.view.action.CreateJobNetAction;
 import com.clustercontrol.jobmanagement.view.action.CreateJobUnitAction;
+import com.clustercontrol.jobmanagement.view.action.CreateReferJobAction;
 import com.clustercontrol.jobmanagement.view.action.DeleteJobAction;
+import com.clustercontrol.jobmanagement.view.action.EditModeAction;
+import com.clustercontrol.jobmanagement.view.action.JobObjectPrivilegeAction;
 import com.clustercontrol.jobmanagement.view.action.ModifyJobAction;
 import com.clustercontrol.jobmanagement.view.action.PasteJobAction;
 import com.clustercontrol.jobmanagement.view.action.RunJobAction;
-import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.view.CommonViewPart;
+import com.clustercontrol.view.ObjectPrivilegeTargetListView;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
 /**
  * ジョブ[一覧]ビュークラスです。
  * 
- * @version 2.0.0
+ * @version 4.1.0
  * @since 1.0.0
  */
-public class JobListView extends CommonViewPart {
+public class JobListView extends CommonViewPart implements ObjectPrivilegeTargetListView {
+	// ログ
+	private static Log m_log = LogFactory.getLog( JobListView.class );
+
 	/** ビューID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.JobListView";
 	/** サッシュ */
-	protected SashForm m_sash = null;
+	private SashForm m_sash = null;
 	/** ジョブツリー用コンポジット */
-	protected JobTreeComposite m_jobTree = null;
+	private JobTreeComposite m_jobTree = null;
 	/** ジョブ[一覧]ビュー用のコンポジット */
-	protected JobListComposite m_jobList = null;
+	private JobListComposite m_jobList = null;
 	/** ジョブツリーアイテム */
-	protected JobTreeItem m_copyJobTreeItem = null;
-	/** 更新フラグ */
-	protected boolean m_update = false;
+	private JobTreeItem m_copyJobTreeItem = null;
 
 	/**
 	 * コンストラクタ
@@ -99,8 +110,9 @@ public class JobListView extends CommonViewPart {
 		gridData.grabExcessVerticalSpace = true;
 		m_sash.setLayoutData(gridData);
 
+		Long start = System.currentTimeMillis();
 		//ジョブ階層ツリー作成
-		m_jobTree = new JobTreeComposite(m_sash, SWT.NONE);
+		m_jobTree = new JobTreeComposite(this, m_sash, SWT.NONE, null);
 
 		//ジョブ一覧作成
 		m_jobList = new JobListComposite(m_sash, SWT.NONE);
@@ -117,6 +129,12 @@ public class JobListView extends CommonViewPart {
 		//ポップアップメニュー作成
 		createContextMenu();
 
+		Long end = System.currentTimeMillis();
+
+		m_log.info("init() : " + (end - start) + "ms");
+		
+		m_jobTree.addToTreeViewerList();
+		
 		//ツリーを開く
 		m_jobTree.getTreeViewer().expandToLevel(2);
 	}
@@ -127,7 +145,7 @@ public class JobListView extends CommonViewPart {
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -158,27 +176,37 @@ public class JobListView extends CommonViewPart {
 	 * @see org.eclipse.jface.action.IToolBarManager
 	 * @see org.eclipse.jface.action.IMenuManager
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ビューのアクションのインスタンスを取得
 		IToolBarManager toolbar = this.getViewSite().getActionBars()
-		.getToolBarManager();
+				.getToolBarManager();
 		ActionContributionItem createJobUnitAction = (ActionContributionItem) toolbar
-		.find(CreateJobUnitAction.ID);
+				.find(CreateJobUnitAction.ID);
 		ActionContributionItem createJobNetAction = (ActionContributionItem) toolbar
-		.find(CreateJobNetAction.ID);
+				.find(CreateJobNetAction.ID);
 		ActionContributionItem createJobAction = (ActionContributionItem) toolbar
-		.find(CreateJobAction.ID);
+				.find(CreateJobAction.ID);
 		ActionContributionItem createFileJobAction = (ActionContributionItem) toolbar
-		.find(CreateFileJobAction.ID);
+				.find(CreateFileJobAction.ID);
+
+		ActionContributionItem createReferJobAction = (ActionContributionItem) toolbar
+				.find(CreateReferJobAction.ID);
+
 		ActionContributionItem deleteJobAction = (ActionContributionItem) toolbar
-		.find(DeleteJobAction.ID);
+				.find(DeleteJobAction.ID);
 		ActionContributionItem modifyJobAction = (ActionContributionItem) toolbar
-		.find(ModifyJobAction.ID);
+				.find(ModifyJobAction.ID);
 		ActionContributionItem runJobAction = (ActionContributionItem) toolbar
-		.find(RunJobAction.ID);
+				.find(RunJobAction.ID);
+		ActionContributionItem editModeAction = (ActionContributionItem) toolbar
+				.find(EditModeAction.ID);
+		ActionContributionItem objPrivilege =
+				(ActionContributionItem) toolbar.find(JobObjectPrivilegeAction.ID);
 
 		//ポップアップメニューにアクションを追加
 		//Ver2.0.0 コピーを追加
+		manager.add(editModeAction.getAction());
+		manager.add(new Separator());
 		CopyJobAction copyJobAction = new CopyJobAction(this);
 		manager.add(copyJobAction);
 		//Ver2.0.0 貼り付けを追加
@@ -189,9 +217,12 @@ public class JobListView extends CommonViewPart {
 		manager.add(createJobNetAction.getAction());
 		manager.add(createJobAction.getAction());
 		manager.add(createFileJobAction.getAction());
+		manager.add(createReferJobAction.getAction());
 		manager.add(modifyJobAction.getAction());
 		manager.add(deleteJobAction.getAction());
 		manager.add(runJobAction.getAction());
+		manager.add(new Separator());
+		manager.add(objPrivilege.getAction());
 
 		//コピー・貼り付けアクションの使用可/不可を設定
 		JobTreeItem select = getSelectJobTreeItem();
@@ -199,31 +230,42 @@ public class JobListView extends CommonViewPart {
 			//コピーアクションの使用可/不可を設定
 			if(select.getData().getType() == JobConstant.TYPE_COMPOSITE){
 				copyJobAction.setEnabled(false);
-
-			} else if (select.getData().getType() == JobConstant.TYPE_JOBUNIT) {
-				if (JobUtil.isReferableJobunit(select, LoginManager.getContextManager().getUserId())) {
-					copyJobAction.setEnabled(true);
-				} else {
-					copyJobAction.setEnabled(false);
-				}
 			} else{
 				copyJobAction.setEnabled(true);
 			}
 			//貼り付けアクションの使用可/不可を設定
 			if(m_copyJobTreeItem != null && m_copyJobTreeItem instanceof JobTreeItem){
-				pasteJobAction.setEnabled(true);
-
-				if (select.getData().getType() == JobConstant.TYPE_JOBUNIT) {
-					if (JobUtil.isReferableJobunit(select, LoginManager.getContextManager().getUserId())) {
-						pasteJobAction.setEnabled(true);
+				// アイテムがコピーされている場合
+				if (select.getData().getType() == JobConstant.TYPE_COMPOSITE) {
+					// ツリーのトップでは貼り付けできる
+					pasteJobAction.setEnabled(true);
+				} else {
+					// ツリーのトップ以外の場合
+					if (JobEditStateUtil.isLockedJobunitId(select.getData().getJobunitId())) {
+						// 編集モードに入っている
+						if (select.getData().getType() == JobConstant.TYPE_JOBUNIT) {
+							// 編集モードの参照可能ジョブユニットでは貼り付けできる
+							pasteJobAction.setEnabled(true);
+						} else if (select.getData().getType() == JobConstant.TYPE_JOBNET) {
+							// 編集モードのジョブネットも貼り付けできる
+							pasteJobAction.setEnabled(true);
+						} else {
+							// それ以外(ジョブ・ファイル転送ジョブ・参照ジョブ)では貼り付けできない
+							pasteJobAction.setEnabled(false);
+						}
 					} else {
+						// 編集モードでないときは貼り付けできない
 						pasteJobAction.setEnabled(false);
 					}
 				}
-
-			}  else{
+			}else {
+				// アイテムがコピーされていない場合
 				pasteJobAction.setEnabled(false);
 			}
+		} else {
+			// アイテムが選択されていない場合
+			pasteJobAction.setEnabled(false);
+			copyJobAction.setEnabled(false);
 		}
 	}
 
@@ -234,14 +276,40 @@ public class JobListView extends CommonViewPart {
 	 * @see com.clustercontrol.jobmanagement.composite.JobTreeComposite#getSelectItem()
 	 * @see com.clustercontrol.jobmanagement.composite.JobListComposite#update(JobTreeItem)
 	 */
+	@Override
 	public void update() {
+		Long start = System.currentTimeMillis();
+		JobEditStateUtil.clearEditStateAll();
+
 		m_jobTree.update();
-
 		JobTreeItem item = this.getJobTreeComposite().getSelectItem();
-
 		m_jobList.update(item);
+		Long end = System.currentTimeMillis();
+		m_log.info("update () : " + (end - start) + "ms");
+	}
 
-		m_update = false;
+	/**
+	 * ビューを更新します
+	 * 指定されたジョブIDに該当するジョブツリーをフォーカスする
+	 * @param jobId
+	 */
+	public void update(String jobId){
+		JobEditStateUtil.clearEditStateAll();
+
+		m_jobTree.update(jobId);
+		JobTreeItem item = this.getJobTreeComposite().getSelectItem();
+		m_jobList.update(item);
+	}
+	/**
+	 * ビューのアクションの有効/無効を設定します。
+	 * 
+	 * @param type ジョブ種別
+	 * @param selection ボタン（アクション）を有効にするための情報
+	 * 
+	 * @see com.clustercontrol.bean.JobConstant
+	 */
+	public void setEnabledAction(int type, ISelection selection) {
+		setEnabledAction(type, "", selection);
 	}
 
 	/**
@@ -252,64 +320,102 @@ public class JobListView extends CommonViewPart {
 	 * 
 	 * @see com.clustercontrol.bean.JobConstant
 	 */
-	public void setEnabledAction(int type, ISelection selection) {
+	public void setEnabledAction(int type, String jobunitId, ISelection selection) {
 
 		super.setEnabledAction(CreateJobUnitAction.ID, selection);
 		super.setEnabledAction(CreateJobNetAction.ID, selection);
 		super.setEnabledAction(CreateJobAction.ID, selection);
 		super.setEnabledAction(CreateFileJobAction.ID, selection);
+		super.setEnabledAction(CreateReferJobAction.ID, selection);
 		super.setEnabledAction(DeleteJobAction.ID, selection);
 		super.setEnabledAction(ModifyJobAction.ID, selection);
+		super.setEnabledAction(JobObjectPrivilegeAction.ID, selection);
 		super.setEnabledAction(RunJobAction.ID, selection);
+		super.setEnabledAction(EditModeAction.ID, selection);
+
+		// 編集モードボタンの押下状態を変更する
+		boolean enable = JobEditStateUtil.isLockedJobunitId(jobunitId);
+		IToolBarManager toolbar = this.getViewSite().getActionBars().getToolBarManager();
+		ActionContributionItem editModeAction = (ActionContributionItem) toolbar.find(EditModeAction.ID);
+		editModeAction.getAction().setChecked(enable);
 
 		if (type == JobConstant.TYPE_COMPOSITE) {
 			super.setEnabledAction(CreateJobUnitAction.ID, true);
 			super.setEnabledAction(CreateJobNetAction.ID, false);
 			super.setEnabledAction(CreateJobAction.ID, false);
 			super.setEnabledAction(CreateFileJobAction.ID, false);
+			super.setEnabledAction(CreateReferJobAction.ID, false);
 			super.setEnabledAction(DeleteJobAction.ID, false);
 			super.setEnabledAction(ModifyJobAction.ID, false);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
 			super.setEnabledAction(RunJobAction.ID, false);
+			super.setEnabledAction(EditModeAction.ID, false);
 		} else if (type == JobConstant.TYPE_JOBUNIT) {
-			super.setEnabledAction(CreateJobUnitAction.ID, false);
-			super.setEnabledAction(CreateJobNetAction.ID, true);
-			super.setEnabledAction(CreateJobAction.ID, true);
-			super.setEnabledAction(CreateFileJobAction.ID, true);
-			super.setEnabledAction(DeleteJobAction.ID, true);
+			super.setEnabledAction(CreateJobUnitAction.ID, false & enable);
+			super.setEnabledAction(CreateJobNetAction.ID, true & enable);
+			super.setEnabledAction(CreateJobAction.ID, true & enable);
+			super.setEnabledAction(CreateFileJobAction.ID, true & enable);
+			super.setEnabledAction(CreateReferJobAction.ID, true & enable);
+			super.setEnabledAction(DeleteJobAction.ID, true & enable);
 			super.setEnabledAction(ModifyJobAction.ID, true);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, true & !enable);
 			super.setEnabledAction(RunJobAction.ID, true);
+			super.setEnabledAction(EditModeAction.ID, true);
 		} else if (type == JobConstant.TYPE_JOBNET) {
-			super.setEnabledAction(CreateJobUnitAction.ID, false);
-			super.setEnabledAction(CreateJobNetAction.ID, true);
-			super.setEnabledAction(CreateJobAction.ID, true);
-			super.setEnabledAction(CreateFileJobAction.ID, true);
-			super.setEnabledAction(DeleteJobAction.ID, true);
+			super.setEnabledAction(CreateJobUnitAction.ID, false & enable);
+			super.setEnabledAction(CreateJobNetAction.ID, true & enable);
+			super.setEnabledAction(CreateJobAction.ID, true & enable);
+			super.setEnabledAction(CreateFileJobAction.ID, true & enable);
+			super.setEnabledAction(CreateReferJobAction.ID, true & enable);
+			super.setEnabledAction(DeleteJobAction.ID, true & enable);
 			super.setEnabledAction(ModifyJobAction.ID, true);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
 			super.setEnabledAction(RunJobAction.ID, true);
+			super.setEnabledAction(EditModeAction.ID, true);
 		} else if (type == JobConstant.TYPE_JOB) {
 			super.setEnabledAction(CreateJobUnitAction.ID, false);
 			super.setEnabledAction(CreateJobNetAction.ID, false);
 			super.setEnabledAction(CreateJobAction.ID, false);
 			super.setEnabledAction(CreateFileJobAction.ID, false);
-			super.setEnabledAction(DeleteJobAction.ID, true);
+			super.setEnabledAction(CreateReferJobAction.ID, false);
+			super.setEnabledAction(DeleteJobAction.ID, true & enable);
 			super.setEnabledAction(ModifyJobAction.ID, true);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
 			super.setEnabledAction(RunJobAction.ID, true);
+			super.setEnabledAction(EditModeAction.ID, true);
 		} else if (type == JobConstant.TYPE_FILEJOB) {
 			super.setEnabledAction(CreateJobUnitAction.ID, false);
 			super.setEnabledAction(CreateJobNetAction.ID, false);
 			super.setEnabledAction(CreateJobAction.ID, false);
 			super.setEnabledAction(CreateFileJobAction.ID, false);
-			super.setEnabledAction(DeleteJobAction.ID, true);
+			super.setEnabledAction(CreateReferJobAction.ID, false);
+			super.setEnabledAction(DeleteJobAction.ID, true & enable);
 			super.setEnabledAction(ModifyJobAction.ID, true);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
 			super.setEnabledAction(RunJobAction.ID, true);
+			super.setEnabledAction(EditModeAction.ID, true);
+		} else if (type == JobConstant.TYPE_REFERJOB) {
+			super.setEnabledAction(CreateJobUnitAction.ID, false);
+			super.setEnabledAction(CreateJobNetAction.ID, false);
+			super.setEnabledAction(CreateJobAction.ID, false);
+			super.setEnabledAction(CreateFileJobAction.ID, false);
+			super.setEnabledAction(CreateReferJobAction.ID, false);
+			super.setEnabledAction(DeleteJobAction.ID, true & enable);
+			super.setEnabledAction(ModifyJobAction.ID, true);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
+			super.setEnabledAction(RunJobAction.ID, true);
+			super.setEnabledAction(EditModeAction.ID, true);
 		} else {
 			super.setEnabledAction(CreateJobUnitAction.ID, false);
 			super.setEnabledAction(CreateJobNetAction.ID, false);
 			super.setEnabledAction(CreateJobAction.ID, false);
 			super.setEnabledAction(CreateFileJobAction.ID, false);
+			super.setEnabledAction(CreateReferJobAction.ID, false);
 			super.setEnabledAction(DeleteJobAction.ID, false);
 			super.setEnabledAction(ModifyJobAction.ID, false);
+			super.setEnabledAction(JobObjectPrivilegeAction.ID, false);
 			super.setEnabledAction(RunJobAction.ID, false);
+			super.setEnabledAction(EditModeAction.ID, false);
 		}
 
 	}
@@ -379,21 +485,64 @@ public class JobListView extends CommonViewPart {
 		m_copyJobTreeItem = copy;
 	}
 
-	/**
-	 * ジョブツリーアイテムの更新フラグを返します。
-	 * 
-	 * @return 更新フラグ
-	 */
-	public boolean isUpdate() {
-		return m_update;
+	@Override
+	public void dispose() {
+		m_jobTree.removeFromTreeViewerList();
+		super.dispose();
 	}
 
-	/**
-	 * ジョブツリーアイテムの更新フラグを設定します。
-	 * 
-	 * @param update 更新フラグ
-	 */
-	public void setUpdate(boolean update) {
-		m_update = update;
+	@Override
+	public List<ObjectBean> getSelectedObjectBeans() {
+
+		// 選択されているスコープを取得する
+		JobTreeItem item = getSelectedJobunitItem();
+
+		// 選択されており、スコープの場合は値を返す
+		List<ObjectBean> objectBeans = new ArrayList<ObjectBean>();
+		if (item != null) {
+			String objectId = item.getData().getJobunitId();
+			String objectType = HinemosModuleConstant.JOB;
+			ObjectBean objectBean = new ObjectBean(objectType, objectId);
+			objectBeans.add(objectBean);
+		}
+		return objectBeans;
+	}
+
+	@Override
+	public String getSelectedOwnerRoleId() {
+
+		// 選択されているスコープを取得する
+		JobTreeItem item = getSelectedJobunitItem();
+
+		// 選択されており、スコープの場合は値を返す
+		String ownerRoleId = null;
+		if (item != null) {
+			ownerRoleId = item.getData().getOwnerRoleId();
+		}
+		return ownerRoleId;
+	}
+
+	private JobTreeItem getSelectedJobunitItem() {
+
+		JobTreeComposite tree = getJobTreeComposite();
+		JobListComposite list = getJobListComposite();
+
+		JobTreeItem item = null;
+		if(tree.getTree().isFocusControl()){
+			item = tree.getSelectItem();
+		}
+		else if(list.getTableViewer().getTable().isFocusControl()){
+			item = list.getSelectItem();
+		}
+		else{
+			// 該当項目なし
+		}
+
+		// 選択されており、ジョブユニットの場合は値を返す
+		if (item != null && item.getData().getType() == JobConstant.TYPE_JOBUNIT) {
+			return item;
+		} else {
+			return null;
+		}
 	}
 }
\ No newline at end of file
