@@ -26,6 +26,7 @@ import org.eclipse.ui.PlatformUI;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
 import com.clustercontrol.jobmanagement.dialog.JobDialog;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.util.JobTreeItemUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
@@ -41,7 +42,7 @@ public class CreateJobUnitAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.CreateJobUnitAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -77,7 +78,7 @@ public class CreateJobUnitAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobListView) {
 			JobListView view = (JobListView) m_view
-			.getAdapter(JobListView.class);
+					.getAdapter(JobListView.class);
 			JobTreeComposite tree = view.getJobTreeComposite();
 			parent = view.getSelectJobTreeItem();
 
@@ -90,7 +91,6 @@ public class CreateJobUnitAction implements IViewActionDelegate {
 				jobInfo.setType(JobConstant.TYPE_JOBUNIT);
 				item = new JobTreeItem();
 				item.setData(jobInfo);
-				item.getData().setUpdate(true);
 				JobTreeItemUtil.addChildren(parent, item);
 
 				JobDialog dialog = new JobDialog(
@@ -100,11 +100,12 @@ public class CreateJobUnitAction implements IViewActionDelegate {
 
 				//ダイアログ表示
 				if (dialog.open() == IDialogConstants.OK_ID) {
-					view.setUpdate(true);
+					JobEditStateUtil.addEditedJobunit(item);
 				} else {
 					JobTreeItemUtil.removeChildren(parent, item);
 				}
-				tree.getTreeViewer().refresh(parent);
+				tree.getTreeViewer().sort(parent);
+				tree.refresh(parent);
 				tree.getTreeViewer().setSelection(
 						new StructuredSelection(parent), true);
 			}
