@@ -22,10 +22,11 @@ import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.ui.IViewActionDelegate;
 import org.eclipse.ui.IViewPart;
 
+import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.JobListComposite;
 import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.util.JobTreeItemUtil;
-import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
@@ -40,7 +41,7 @@ public class DeleteJobAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.DeleteJobAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -76,7 +77,7 @@ public class DeleteJobAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobListView) {
 			JobListView view = (JobListView) m_view
-			.getAdapter(JobListView.class);
+					.getAdapter(JobListView.class);
 			JobTreeComposite tree = view.getJobTreeComposite();
 			JobListComposite list = view.getJobListComposite();
 			if (tree.getTree().isFocusControl()) {
@@ -94,19 +95,27 @@ public class DeleteJobAction implements IViewActionDelegate {
 			if (parent instanceof JobTreeItem && item instanceof JobTreeItem) {
 				// 確認ダイアログを生成
 				String message = Messages.getString("job") + "["
-				+ item.getData().getId() + "]"
-				+ Messages.getString("message.job.2");
+						+ item.getData().getId() + "]"
+						+ Messages.getString("message.job.2");
 				if (MessageDialog.openQuestion(
 						null,
 						Messages.getString("confirmed"),
 						message)) {
 					JobTreeItemUtil.removeChildren(parent, item);
-					JobUtil.setEditFlg(parent);
-					parent.getData().setUpdate(true);
 
-					view.setUpdate(true);
+					if (item.getData().getType() == JobConstant.TYPE_JOBUNIT) {
+						// ジョブユニットの削除
+						JobEditStateUtil.removeEditedJobunit(item);
+						if (JobEditStateUtil.getLockedJobunitBackup(item.getData()) != null) {
+							// マネージャから取得してきたジョブユニット
+							JobEditStateUtil.addDeletedJobunit(item);
+						}
+					} else {
+						// ジョブユニット以外の削除はジョブユニットの編集にあたる
+						JobEditStateUtil.addEditedJobunit(item);
+					}
 
-					tree.getTreeViewer().refresh(parent);
+					tree.refresh(parent);
 					tree.getTreeViewer().setSelection(
 							new StructuredSelection(parent), true);
 				}
