@@ -22,15 +22,22 @@ import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;
 /**
  * ログファイル監視設定情報のBeanクラス<BR>
  * 
- * @version 4.0.0
+ * @version 4.1.0
  */
 @XmlType(namespace = "http://monitor.ws.clustercontrol.com")
 public class LogfileCheckInfo extends MonitorCheckInfo {
 
-	private static final long serialVersionUID = -6043000422980192807L;
-	/** ファイル名 */
+	private static final long serialVersionUID = -5875124203155944914L;
+
+	/** ログファイル名 */
 	private String m_logfile;
 
+	/** ディレクトリ */
+	private String m_directory;
+
+	/** ファイル名 */
+	private String m_fileName;
+
 	public LogfileCheckInfo(){
 	}
 
@@ -41,4 +48,29 @@ public class LogfileCheckInfo extends MonitorCheckInfo {
 	public void setLogfile(String logfile) {
 		this.m_logfile = logfile;
 	}
+
+	/**
+	 * ディレクトリ
+	 **/
+	public String getDirectory() {
+		return m_directory;
+	}
+	/**
+	 * ディレクトリ
+	 **/
+	public void setDirectory(String directory) {
+		this.m_directory = directory;
+	}
+	/**
+	 *ファイル名
+	 **/
+	public String getFileName() {
+		return m_fileName;
+	}
+	/**
+	 *ファイル名
+	 **/
+	public void setFileName(String fileName) {
+		this.m_fileName = fileName;
+	}
 }
