@@ -94,7 +94,7 @@ public class MaintenanceEnableAction implements IViewActionDelegate {
 			return;
 		}
 
-		boolean hasRole = true; //設定権限を持っているかどうか
+		boolean hasRole = true;
 		// 実行
 		for(Object o : objs){
 			maintenanceId = (String) ((ArrayList)o).get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
@@ -102,7 +102,7 @@ public class MaintenanceEnableAction implements IViewActionDelegate {
 			try{
 				MaintenanceEndpointWrapper.setMaintenanceStatus(maintenanceId, true);
 				successList.append(maintenanceId + "\n");
-			}catch (InvalidRole_Exception e) {
+			} catch (InvalidRole_Exception e) {
 				failureList.append(maintenanceId + "\n");
 				m_log.warn("run() setMaintenanceStatus maintenanceId=" + maintenanceId + ", " + e.getMessage(), e);
 				hasRole = false;
@@ -117,7 +117,7 @@ public class MaintenanceEnableAction implements IViewActionDelegate {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
 		}
-		
+
 		// 成功ダイアログ
 		if(successList.length() != 0){
 			args = new String[]{ successList.toString() } ;
