@@ -40,7 +40,6 @@ import org.eclipse.ui.IWorkbenchPage;
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.monitor.action.CommentEvent;
 import com.clustercontrol.monitor.action.GetEventListTableDefine;
 import com.clustercontrol.monitor.dialog.EventInfoDialog;
@@ -51,6 +50,7 @@ import com.clustercontrol.monitor.util.MonitorEndpointWrapper;
 import com.clustercontrol.monitor.view.EventView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.monitor.EventDataInfo;
 import com.clustercontrol.ws.monitor.EventFilterInfo;
 import com.clustercontrol.ws.monitor.HinemosUnknown_Exception;
@@ -295,6 +295,10 @@ public class EventListComposite extends Composite {
 		if (infoList == null) {
 			infoList = new ViewListInfo();
 			infoList.setTotal(0);
+			infoList.setCritical(0);
+			infoList.setWarning(0);
+			infoList.setInfo(0);
+			infoList.setUnKnown(0);
 		}
 
 		ArrayList list = ConvertListUtil.eventLogDataListToArrayList(infoList.getEventList());
@@ -397,6 +401,10 @@ public class EventListComposite extends Composite {
 		if (infoList == null) {
 			infoList = new ViewListInfo();
 			infoList.setTotal(0);
+			infoList.setCritical(0);
+			infoList.setWarning(0);
+			infoList.setInfo(0);
+			infoList.setUnKnown(0);
 		}
 
 		ArrayList list = ConvertListUtil.eventLogDataListToArrayList(infoList.getEventList());
@@ -439,7 +447,7 @@ public class EventListComposite extends Composite {
 	 * 
 	 * @param list ビュー一覧情報
 	 */
-	protected void updateStatus(ViewListInfo list) {
+	private void updateStatus(ViewListInfo list) {
 
 		// 表示最大件数の取得
 		int messageNumber = ClusterControlPlugin.getDefault().getPreferenceStore().getInt(MonitorPreferencePage.P_EVENT_MAX);
