@@ -34,6 +34,7 @@ import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
+import com.clustercontrol.monitor.run.dialog.CommonMonitorDialog;
 import com.clustercontrol.repository.FacilityPath;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
@@ -57,16 +58,20 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 public class MonitorBasicScopeComposite extends MonitorBasicComposite {
 
 	/** スコープ テキストボックス。 */
-	protected Text m_textScope = null;
+	private Text m_textScope = null;
 
 	/** 参照 ボタン。 */
-	protected Button m_buttonScope = null;
+	private Button m_buttonScope = null;
 
 	/** 選択されたスコープのファシリティID。 */
-	protected String m_facilityId = null;
+	private String m_facilityId = null;
 
 	/** 未登録ノード スコープを表示するかフラグ*/
-	protected boolean m_unregistered = false;
+	private boolean m_unregistered = false;
+
+	/** オーナーロールID*/
+	private String m_ownerRoleId = null;
+
 
 	/**
 	 * インスタンスを返します。
@@ -81,9 +86,9 @@ public class MonitorBasicScopeComposite extends MonitorBasicComposite {
 	 * @see com.clustercontrol.monitor.run.composite.MonitorBasicComposite#MonitorBasicComposite(Composite, int)
 	 * @see #initialize()
 	 */
-	public MonitorBasicScopeComposite(Composite parent, int style ,boolean unregistered) {
-		super(parent, style);
-		m_unregistered = unregistered;
+	public MonitorBasicScopeComposite(Composite parent, int style ,boolean unregistered, CommonMonitorDialog parentDialog) {
+		super(parent, style, parentDialog);
+		this.m_unregistered = unregistered;
 		this.initialize();
 	}
 
@@ -142,7 +147,7 @@ public class MonitorBasicScopeComposite extends MonitorBasicComposite {
 				// シェルを取得
 				Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
 
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell,false,m_unregistered);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, m_ownerRoleId, false, m_unregistered);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem item = dialog.getSelectItem();
 					FacilityInfo info = item.getData();
@@ -182,18 +187,19 @@ public class MonitorBasicScopeComposite extends MonitorBasicComposite {
 			this.m_textScope.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 	}
-
+	
 	/**
 	 * 引数で指定された監視情報の値を、各項目に設定します。
 	 * 
 	 * @param info 設定値として用いる監視情報
+	 * @param updateFlg 更新するか否か（true:更新する）
 	 * 
 	 * @see com.clustercontrol.monitor.run.composite.MonitorBasicComposite#setInputData(MonitorInfo)
 	 */
 	@Override
-	public void setInputData(MonitorInfo info ) {
+	public void setInputData(MonitorInfo info, boolean updateFlg) {
 
-		super.setInputData(info);
+		super.setInputData(info, updateFlg);
 
 		if(info != null){
 			if (info.getScope() != null) {
@@ -275,4 +281,14 @@ public class MonitorBasicScopeComposite extends MonitorBasicComposite {
 	public String getFacilityId() {
 		return m_facilityId;
 	}
+
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.m_ownerRoleId = ownerRoleId;
+		this.m_textScope.setText("");
+		this.m_facilityId = null;
+	}
+	
+	public String getOwnerRoleId(){
+		return this.m_ownerRoleId;
+	}
 }
\ No newline at end of file
