@@ -686,7 +686,7 @@ public class NumericValueInfoComposite extends Composite {
 		// （通知・警告以外）
 		label = new Label(this, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE*2;
+		gridData.horizontalSpan = WIDTH_VALUE*3;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -695,7 +695,7 @@ public class NumericValueInfoComposite extends Composite {
 		// 空白
 		label = new Label(this, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 7;
+		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -913,10 +913,10 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -956,7 +956,7 @@ public class NumericValueInfoComposite extends Composite {
 	 * @param priority 重要度
 	 * @return 数値監視の判定情報
 	 */
-	protected MonitorNumericValueInfo getDefaultValueInfo(MonitorInfo info, int priority) {
+	private MonitorNumericValueInfo getDefaultValueInfo(MonitorInfo info, int priority) {
 
 		MonitorNumericValueInfo value = new MonitorNumericValueInfo();
 		value.setMonitorId(info.getMonitorId());
