@@ -18,15 +18,22 @@ package com.clustercontrol.monitor.run.composite;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.viewers.DoubleClickEvent;
+import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Table;
+import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.dialog.ValidateResult;
+import com.clustercontrol.monitor.run.dialog.StringValueInfoCreateDialog;
 import com.clustercontrol.monitor.run.util.StringValueInfoManager;
+import com.clustercontrol.monitor.run.viewer.StringValueListTableViewer;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 import com.clustercontrol.ws.monitor.MonitorStringValueInfo;
 
@@ -108,6 +115,24 @@ public class StringValueListComposite extends Composite {
 		// テーブルビューアの作成
 		this.m_tableViewer = new StringValueListTableViewer(table);
 		this.m_tableViewer.createTableColumn(this.m_tableDefine);
+		this.m_tableViewer.addDoubleClickListener(new IDoubleClickListener() {
+			@Override
+			public void doubleClick(DoubleClickEvent event) {
+				MonitorStringValueInfo info = getFilterItem();
+				if (info != null) {
+					Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
+					StringValueInfoCreateDialog dialog = new StringValueInfoCreateDialog(shell, info.getIdentifier());
+					if (dialog.open() == IDialogConstants.OK_ID) {
+						dialog.getInputData();
+						Table table = getTableViewer().getTable();
+						int selectIndex = table.getSelectionIndex();
+						StringValueInfoManager.getInstance().modify(dialog.getInputData());
+						table.setSelection(selectIndex);
+						update();
+					}
+				}
+			}
+		});
 
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -163,7 +188,7 @@ public class StringValueListComposite extends Composite {
 	 * 判定情報一覧を取得し、テーブルビューアーにセットします。
 	 * 
 	 * @see com.clustercontrol.monitor.run.util.StringValueInfoManager#get()
-	 * @see com.clustercontrol.monitor.run.composite.StringValueListTableViewer
+	 * @see com.clustercontrol.monitor.run.viewer.StringValueListTableViewer
 	 */
 	@Override
 	public void update() {
