@@ -89,7 +89,11 @@ public class MonitorEnableAction implements IViewActionDelegate {
 
 			targetIdList.put(monitorId, monitorTypeId);
 
-			targetList.append(monitorId + "\n");
+			if (targetList.length() > 0) {
+				targetList.append(", ");
+				
+			}
+			targetList.append(monitorId);
 		}
 
 		// 実行確認(NG→終了)
@@ -101,7 +105,7 @@ public class MonitorEnableAction implements IViewActionDelegate {
 			return;
 		}
 
-		boolean hasRole = true; //設定権限を持っているかどうか
+		boolean hasRole = true;
 		// 実行
 		for(String targetId : targetIdList.keySet()){
 
@@ -110,13 +114,22 @@ public class MonitorEnableAction implements IViewActionDelegate {
 
 			try{
 				MonitorSettingEndpointWrapper.setStatusMonitor(monitorId, monitorTypeId, true);
-				successList.append(targetId + "\n");
-			}catch (InvalidRole_Exception e) {
-				failureList.append(targetId + "\n");
+				if (successList.length() > 0) {
+					successList.append(", ");
+				}
+				successList.append(targetId);
+			} catch (InvalidRole_Exception e) {
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
 				m_log.warn("run() setStatusMonitor monitorId=" + monitorId + ", " + e.getMessage(), e);
 				hasRole = false;
 			}catch (Exception e) {
-				failureList.append(targetId + "\n");
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
 				m_log.warn("run() setStatusMonitor monitorId=" + monitorId + ", " + e.getMessage(), e);
 			}
 		}
@@ -126,7 +139,7 @@ public class MonitorEnableAction implements IViewActionDelegate {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
 		}
-		
+
 		// 成功ダイアログ
 		if(successList.length() != 0){
 			args = new String[]{ successList.toString() } ;
