@@ -87,4 +87,29 @@ public class GetNotify {
 		}
 		return records;
 	}
+
+	/**
+	 * オーナーロールIDを条件として通知情報一覧を返します。<BR>
+	 * マネージャにSessionBean経由でアクセスします。
+	 * 
+	 * @return 通知情報一覧
+	 */
+	public List<NotifyInfo> getNotifyListByOwnerRole(String ownerRoleId) throws InvalidRole_Exception{
+
+		List<NotifyInfo> records = null;
+		try {
+			records = NotifyEndpointWrapper.getNotifyListByOwnerRole(ownerRoleId);
+		} catch (InvalidRole_Exception e) {
+			MessageDialog.openInformation(null, Messages.getString("message"),
+					Messages.getString("message.accesscontrol.16"));
+			throw e;
+		} catch (Exception e) {
+			m_log.warn("getNotifyListByOwnerRole(), " + e.getMessage(), e);
+			MessageDialog.openError(
+					null,
+					Messages.getString("failed"),
+					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
+		return records;
+	}
 }
\ No newline at end of file
