@@ -60,7 +60,7 @@ public class NotifyIdListComposite extends Composite {
 	/** 通知ID ラベル。 */
 	private Label m_labelNotifyId = null;
 
-	protected Table m_NotifyIdTable = null;
+	private Table m_NotifyIdTable = null;
 
 	/**選　択 ボタン。 */
 	private Button m_buttonRefer = null;
@@ -70,6 +70,8 @@ public class NotifyIdListComposite extends Composite {
 
 	private int notifyIdType = 0;
 
+	private String m_ownerRoleId = null;
+
 	/**
 	 * インスタンスを返します。
 	 * <p>
@@ -190,14 +192,13 @@ public class NotifyIdListComposite extends Composite {
 		this.m_buttonRefer.setText(Messages.getString("select")); //$NON-NLS-1$
 		this.m_buttonRefer.addSelectionListener(new SelectionAdapter() {
 			@Override
-			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
 
 				Shell shell = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getShell();
+						.getActiveWorkbenchWindow().getShell();
 
 				// ダイアログ表示及び終了処理
-				NotifyListDialog dialog = new NotifyListDialog(shell, true, notifyIdType);
+				NotifyListDialog dialog = new NotifyListDialog(shell, true, notifyIdType, m_ownerRoleId);
 				if (notify != null) {
 					dialog.setSelectNotify(notify);
 				}
@@ -230,6 +231,10 @@ public class NotifyIdListComposite extends Composite {
 		this.m_buttonRefer.setEnabled(enabled);
 		this.m_NotifyIdTable.setEnabled(enabled);
 	}
+	
+	public void setButtonEnabled(boolean enabled) {
+		this.m_buttonRefer.setEnabled(enabled);
+	}
 
 	/**
 	 * 通知IDを返します。
@@ -238,7 +243,6 @@ public class NotifyIdListComposite extends Composite {
 	 * 
 	 * @see org.eclipse.swt.widgets.Combo#getText()
 	 */
-	@SuppressWarnings("unchecked")
 	public List<NotifyRelationInfo> getNotify() {
 		return notify;
 	}
@@ -262,7 +266,7 @@ public class NotifyIdListComposite extends Composite {
 
 		for (int i = 0; i < notify.size(); i++) {
 			TableItem ti = new TableItem(m_NotifyIdTable, 0);
-			nri = (NotifyRelationInfo) ((ArrayList) notify).get(i);
+			nri = ((ArrayList<NotifyRelationInfo>) notify).get(i);
 			String notifyType = NotifyTypeUtil.typeToString(nri.getNotifyType());
 
 			String[] repData = { nri.getNotifyId(), notifyType };
@@ -283,7 +287,7 @@ public class NotifyIdListComposite extends Composite {
 			NotifyRelationInfo nri ;
 
 			for(int i = 0; i < notify.size(); i++){
-				nri =(NotifyRelationInfo)((ArrayList)notify).get(i);
+				nri =((ArrayList<NotifyRelationInfo>)notify).get(i);
 				nri.setNotifyGroupId(string);
 			}
 			return true;
@@ -292,4 +296,14 @@ public class NotifyIdListComposite extends Composite {
 		return false;
 	}
 
+	public String getOwnerRoleId() {
+		return m_ownerRoleId;
+	}
+
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.m_ownerRoleId = ownerRoleId;
+		m_NotifyIdTable.removeAll();
+		this.notify = null;
+	}
+
 }
\ No newline at end of file
