@@ -15,8 +15,6 @@ Copyright (C) 2006 NTT DATA Corporation
 
 package com.clustercontrol.notify.composite;
 
-import java.util.ArrayList;
-
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ListViewer;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -38,7 +36,7 @@ public class NotifyTypeListComposite extends Composite {
 	//	 ----- instance フィールド ----- //
 
 	/** 選択アイテム */
-	private ArrayList<Object> selectItem = null;
+	private Integer selectItem = null;
 
 	/** リストビューア */
 	private ListViewer notifyTypeList = null;
@@ -55,7 +53,7 @@ public class NotifyTypeListComposite extends Composite {
 	/**
 	 * コンポジットを生成します。
 	 */
-	protected void createContents() {
+	private void createContents() {
 
 		// コンポジットのレイアウト定義
 		GridLayout layout = new GridLayout();
@@ -72,7 +70,7 @@ public class NotifyTypeListComposite extends Composite {
 			@Override
 			public void selectionChanged(SelectionChangedEvent event) {
 				StructuredSelection selection = (StructuredSelection) event.getSelection();
-				selectItem = (ArrayList<Object>)selection.getFirstElement();
+				selectItem = (Integer)selection.getFirstElement();
 			}
 		});
 
@@ -92,7 +90,7 @@ public class NotifyTypeListComposite extends Composite {
 	 * 
 	 * @return ツリーアイテム
 	 */
-	public ArrayList<Object> getSelectItem() {
+	public Integer getSelectItem() {
 		return this.selectItem;
 	}
 
