@@ -29,6 +29,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.composite.NotifyBasicComposite;
@@ -53,6 +55,9 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 	/** 変更対象の通知ID。 */
 	protected String notifyId = null;
 
+	/** 変更するかどうかのフラグ（true：変更する） modify、copy時に使用  */
+	protected boolean updateFlg = false;
+
 	/** 通知基本情報 */
 	protected NotifyBasicComposite m_notifyBasic = null;
 
@@ -65,7 +70,11 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 	/** この設定を有効にする */
 	protected Button m_confirmValid = null;
 
-	protected int notifyIdType = 0;
+	private int notifyIdType = 0;
+	
+	/** オーナーロールID */
+	private String ownerRoleId = null;
+
 
 	// ----- コンストラクタ ----- //
 
@@ -89,13 +98,14 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新するか否か（true:更新する）
 	 */
-	public NotifyBasicCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
+	public NotifyBasicCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
 		super(parent);
 
 		this.notifyId = notifyId;
-		this.referenceFlg = referenceFlg;
+		this.updateFlg = updateFlg;
+		this.referenceFlg = false;
 	}
 
 	// ----- instance メソッド ----- //
@@ -127,7 +137,7 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 		/*
 		 * 通知基本情報
 		 */
-		m_notifyBasic = new NotifyBasicComposite(parent, SWT.NONE, this.notifyId, notifyIdType);
+		m_notifyBasic = new NotifyBasicComposite(parent, SWT.NONE, this.notifyId, notifyIdType, this);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -163,6 +173,8 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 		label.setLayoutData(gridData);
 
 
+
+
 		/*
 		 * 継承先で各種通知の設定を行う
 		 */
@@ -317,5 +329,22 @@ public class NotifyBasicCreateDialog extends CommonDialog {
 	protected void customizeSettingDialog(Composite parent){
 
 	}
+	
+	public String getOwnerRoleId() {
+		return ownerRoleId;
+	}
+
+	/**
+	 * オーナーロールIDを設定します。
+	 * 継承先クラスにてオーナーロールIDに関連するオブジェクト権限を持つ入力項目をクリアします。
+	 */
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.ownerRoleId = ownerRoleId;
+	}
+	
+	
+	public boolean getUpdateFlg(){
+		return updateFlg;
+	}
 
 }
\ No newline at end of file
