@@ -51,10 +51,10 @@ import com.clustercontrol.ws.notify.NotifyEventInfo;
 public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 		= 1;
+	private static final int WIDTH_PRIORITY 		= 2;
 
 	/** カラム数（通知）。 */
-	private static final int WIDTH_NOTIFY	 		= 1;
+	private static final int WIDTH_NOTIFY	 		= 2;
 
 	/** カラム数（状態）。 */
 	private static final int WIDTH_STATE		= 3;
@@ -63,7 +63,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	private static final int WIDTH_INHIBITION_FLG 	= 2;
 
 	/** カラム数（空欄）。 */
-	private static final int WIDTH_BLANK 			= 5;
+	private static final int WIDTH_BLANK 			= 3;
 
 	// ----- instance フィールド ----- //
 
@@ -76,7 +76,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** 通知（通知） チェックボックス。 */
 	private Button m_checkEventNormalInfo = null;
@@ -116,10 +116,10 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyEventCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+	public NotifyEventCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -305,7 +305,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -346,15 +346,6 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		else {
 			this.m_confirmValid.setSelection(true);
 		}
-
-		// 入力制御
-		if(this.referenceFlg){
-			this.setEnabled(false);
-		}
-		else{
-			this.setEnabled(true);
-		}
-
 	}
 
 	/**
@@ -366,10 +357,10 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param checkEventInhibition 抑制チェックボックス
 	 * @param comboEventInhibition 抑制状態コンボボックス
 	 */
-	private void setInputDataForEvent(NotifyEventInfo info,
+	protected void setInputDataForEvent(NotifyEventInfo info,
 			Button checkEventNormal,
 			Combo comboEventNormal
-	) {
+			) {
 		// イベント通知
 		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
 			checkEventNormal.setSelection(true);
@@ -445,13 +436,13 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知イベント情報
 	 * 
 	 */
-	protected ArrayList<NotifyEventInfo> createInputDataForEvent(ArrayList<NotifyEventInfo> list,
+	private ArrayList<NotifyEventInfo> createInputDataForEvent(ArrayList<NotifyEventInfo> list,
 			int priority,
 			Button checkEventNormal,
 			Combo comboEventNormal,
 			Button checkEventInhibition,
 			Combo comboEventInhibition
-	) {
+			) {
 
 		if(list == null)
 			return null;
@@ -509,7 +500,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if(info != null){
-			if(this.notifyId == null){
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			}
@@ -595,10 +586,10 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -619,7 +610,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckEventNormal(Composite parent) {
+	private Button getCheckEventNormal(Composite parent) {
 
 		// チェックボックス（通知する）
 		Button button = new Button(parent, SWT.CHECK);
@@ -638,7 +629,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたコンボボックス
 	 */
-	protected Combo getComboEventNormal(Composite parent) {
+	private Combo getComboEventNormal(Composite parent) {
 
 		// コンボボックス（通知状態）
 		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
@@ -660,7 +651,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckEventInhibition(Composite parent) {
+	private Button getCheckEventInhibition(Composite parent) {
 
 		// チェックボックス（抑制する）
 		Button button = new Button(parent, SWT.CHECK);
@@ -679,7 +670,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたコンボボックス
 	 */
-	protected Combo getComboEventInhibition(Composite parent) {
+	private Combo getComboEventInhibition(Composite parent) {
 
 		// コンボボックス（抑制時の状態）
 		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
