@@ -55,19 +55,13 @@ import com.clustercontrol.ws.notify.NotifyMailInfo;
 public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 		= 1;
+	private static final int WIDTH_PRIORITY 		= 2;
 
 	/** カラム数（チェックボックス）。 */
-	private static final int WIDTH_CHECK 			= 1;
+	private static final int WIDTH_CHECK 			= 2;
 
 	/** カラム数（メッセールアドレス）。 */
-	private static final int WIDTH_MAIL_ADDRESS		= 6;
-
-	/** カラム数（抑制）。 */
-	private static final int WIDTH_INHIBITION_FLG	= 2;
-
-	/** カラム数（空欄）。 */
-	private static final int WIDTH_BLANK 			= 5;
+	private static final int WIDTH_MAIL_ADDRESS		= 11;
 
 	// ----- instance フィールド ----- //
 
@@ -80,7 +74,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** メールテンプレートID情報コンポジット */
 	private MailTemplateIdListComposite m_compositeMailTemplateIdList = null;
@@ -103,6 +97,9 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	/** メールアドレス（重要度：不明） テキスト。 */
 	private Text m_textMailAddressUnknown = null;
 
+	/** オーナーロールID */
+	private String ownerRoleId = null;
+
 	// ----- コンストラクタ ----- //
 
 	/**
@@ -123,10 +120,10 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyMailCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+	public NotifyMailCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -154,7 +151,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			info = new NotifyInfo();
 		}
 		this.setInputData(info);
-
 	}
 
 	/**
@@ -248,14 +244,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("email.address.ssv"));
 
-		// ラベル（空欄）
-		label = new Label(groupMail, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		//　メール　重要度：情報
 		label = this.getLabelPriority(groupMail, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkMailNormalInfo = this.getCheckMailNormal(groupMail);
@@ -274,15 +262,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 
-		// ラベル（空欄）
-		label = new Label(groupMail, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
-
 		//　メール　重要度：警告
 		label = this.getLabelPriority(groupMail, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkMailNormalWarning = this.getCheckMailNormal(groupMail);
@@ -301,14 +280,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 
-		// ラベル（空欄）
-		label = new Label(groupMail, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		//　メール　重要度：危険
 		label = this.getLabelPriority(groupMail, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkMailNormalCritical = this.getCheckMailNormal(groupMail);
@@ -327,14 +298,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			}
 		});
 
-		// ラベル（空欄）
-		label = new Label(groupMail, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		//　メール　重要度：不明
 		label = this.getLabelPriority(groupMail, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkMailNormalUnknown = this.getCheckMailNormal(groupMail);
@@ -352,15 +315,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 				update();
 			}
 		});
-
-		// ラベル（空欄）
-		label = new Label(groupMail, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 	}
 
 	/**
@@ -423,7 +377,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -469,14 +423,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 			this.m_confirmValid.setSelection(true);
 		}
 
-		// 入力制御
-		if(this.referenceFlg){
-			this.setEnabled(false);
-		}
-		else{
-			this.setEnabled(true);
-		}
-
 		// 必須入力項目を可視化
 		this.update();
 	}
@@ -489,11 +435,11 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * @param textMailAddress メールアドレステキストボックス
 	 * @param checkMailInhibition 抑制チェックボックス
 	 */
-	private void setInputDataForMail(NotifyMailInfo info,
+	protected void setInputDataForMail(NotifyMailInfo info,
 			Button checkMailNormal,
 			Text textMailAddress,
 			Button checkMailInhibition
-	) {
+			) {
 		// メール通知
 		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
 			checkMailNormal.setSelection(true);
@@ -539,7 +485,6 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		}
 
 		// メール情報
-
 		ArrayList<NotifyMailInfo> list = new ArrayList<NotifyMailInfo>();
 		list = this.createInputDataForMail(list, PriorityConstant.TYPE_INFO,	this.m_checkMailNormalInfo, this.m_textMailAddressInfo);
 		list = this.createInputDataForMail(list, PriorityConstant.TYPE_WARNING,	this.m_checkMailNormalWarning, this.m_textMailAddressWarning);
@@ -571,11 +516,11 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知メール情報
 	 * 
 	 */
-	protected ArrayList<NotifyMailInfo> createInputDataForMail(ArrayList<NotifyMailInfo> list,
+	private ArrayList<NotifyMailInfo> createInputDataForMail(ArrayList<NotifyMailInfo> list,
 			int priority,
 			Button checkMailNormal,
 			Text textMailAddress
-	) {
+			) {
 
 		if(list == null)
 			return null;
@@ -637,7 +582,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if(info != null){
-			if(this.notifyId == null){
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			}
@@ -724,10 +669,10 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -748,7 +693,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckMailNormal(Composite parent) {
+	private Button getCheckMailNormal(Composite parent) {
 
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
@@ -767,7 +712,7 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
-	protected Text getTextMailAddress(Composite parent) {
+	private Text getTextMailAddress(Composite parent) {
 
 		// テキスト（送信先（セミコロン区切り））
 		Text text = new Text(parent, SWT.BORDER);
@@ -780,23 +725,10 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
 		return text;
 	}
 
-	/**
-	 * メールの抑制のチェックボックスを返します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @return 生成されたチェックボックス
-	 */
-	protected Button getCheckMailInhibition(Composite parent) {
-
-		// チェックボックス（抑制する）
-		Button button = new Button(parent, SWT.CHECK);
-		GridData gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		button.setLayoutData(gridData);
-
-		return button;
+	@Override
+	public void setOwnerRoleId(String ownerRoleId) {
+		super.setOwnerRoleId(ownerRoleId);
+		this.m_compositeMailTemplateIdList.update(ownerRoleId);
 	}
 
 }
\ No newline at end of file
