@@ -33,6 +33,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.PlatformUI;
 
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.notify.mail.dialog.MailTemplateCreateDialog;
 import com.clustercontrol.notify.mail.util.MailTemplateEndpointWrapper;
 import com.clustercontrol.util.Messages;
@@ -180,7 +181,7 @@ public class MailTemplateIdListComposite extends Composite {
 					Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
 
 					// メールテンプレート登録/変更画面を開く
-					MailTemplateCreateDialog dialog = new MailTemplateCreateDialog(shell, mailTemplateId, true);
+					MailTemplateCreateDialog dialog = new MailTemplateCreateDialog(shell, mailTemplateId, PropertyDefineConstant.MODE_SHOW);
 					dialog.open();
 				}
 			}
@@ -197,6 +198,17 @@ public class MailTemplateIdListComposite extends Composite {
 	 */
 	@Override
 	public void update() {
+	}
+
+	/**
+	 * コンポジットを更新します。<BR>
+	 * メールテンプレートID一覧情報を取得し、メールテンプレートID一覧コンポジットにセットします。
+	 * 
+	 * @param ownerRoleId
+	 */
+	public void update(String ownerRoleId) {
+		// 初期化
+		this.m_comboMailTemplateId.removeAll();
 
 		// 空欄
 		this.m_comboMailTemplateId.add("");
@@ -205,8 +217,7 @@ public class MailTemplateIdListComposite extends Composite {
 		List<String> list = null;
 
 		try {
-			List<MailTemplateInfo> listTmp = MailTemplateEndpointWrapper.getMailTemplateList();
-
+			List<MailTemplateInfo> listTmp = MailTemplateEndpointWrapper.getMailTemplateListByOwnerRole(ownerRoleId);
 			list = new ArrayList<String>();
 			for (MailTemplateInfo info : listTmp) {
 				list.add(info.getMailTemplateId());
