@@ -23,11 +23,15 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
-import com.clustercontrol.composite.CommonTableViewer;
+import com.clustercontrol.bean.Property;
 import com.clustercontrol.notify.mail.action.GetMailTemplate;
 import com.clustercontrol.notify.mail.action.GetMailTemplateListTableDefine;
+import com.clustercontrol.notify.mail.composite.actioin.MailTemplateDoubleClickListener;
+import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.mailtemplate.MailTemplateInfo;
 ;
 
@@ -42,6 +46,12 @@ public class MailTemplateListComposite extends Composite {
 	/** テーブルビューアー。 */
 	private CommonTableViewer tableViewer = null;
 
+	/** 合計ラベル */
+	private Label totalLabel = null;
+
+	/** 検索条件 */
+	private Property condition = null;
+
 	/**
 	 * インスタンスを返します。
 	 * <p>
@@ -72,7 +82,7 @@ public class MailTemplateListComposite extends Composite {
 		layout.marginHeight = 0;
 		layout.marginWidth = 0;
 
-		Table table = new Table(this, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL
+		Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
@@ -90,11 +100,20 @@ public class MailTemplateListComposite extends Composite {
 				GetMailTemplateListTableDefine.SORT_COLUMN_INDEX,
 				GetMailTemplateListTableDefine.SORT_ORDER);
 
+		// ダブルクリックリスナの追加
+		this.tableViewer.addDoubleClickListener(new MailTemplateDoubleClickListener(this));
+
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 
-		this.update();
+		// 合計ラベルの作成
+		this.totalLabel = new Label(this, SWT.RIGHT);
+		gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.verticalAlignment = GridData.FILL;
+		this.totalLabel.setLayoutData(gridData);
+
 	}
 
 	/**
@@ -106,6 +125,15 @@ public class MailTemplateListComposite extends Composite {
 		return this.tableViewer;
 	}
 
+	/**
+	 * このコンポジットが利用するテーブルを返します。
+	 * 
+	 * @return テーブル
+	 */
+	public Table getTable() {
+		return this.tableViewer.getTable();
+	}
+
 	/**
 	 * コンポジットを更新します。<BR>
 	 * メールテンプレート一覧情報を取得し、テーブルビューアーにセットします。
@@ -128,6 +156,7 @@ public class MailTemplateListComposite extends Composite {
 			ArrayList<Object> a = new ArrayList<Object>();
 			a.add(mailTemplateInfo.getMailTemplateId());
 			a.add(mailTemplateInfo.getDescription());
+			a.add(mailTemplateInfo.getOwnerRoleId());
 			a.add(mailTemplateInfo.getRegUser());
 			if(mailTemplateInfo.getRegDate() == null){
 				a.add(null);
@@ -147,5 +176,15 @@ public class MailTemplateListComposite extends Composite {
 
 		// テーブル更新
 		this.tableViewer.setInput(listInput);
+
+		// 合計欄更新
+		String[] args = { String.valueOf(list.size()) };
+		String message = null;
+		if (this.condition == null) {
+			message = Messages.getString("records", args);
+		} else {
+			message = Messages.getString("filtered.records", args);
+		}
+		this.totalLabel.setText(message);
 	}
 }
\ No newline at end of file
