@@ -35,8 +35,11 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.composite.RoleIdListComposite;
 import com.clustercontrol.composite.TextWithParameterComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.mail.util.MailTemplateEndpointWrapper;
@@ -69,10 +72,10 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	private MailTemplateInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
-	/** 参照フラグ。 */
-	private boolean referenceFlg = false;
+	/** ダイアログ表示時の処理タイプ */
+	private int mode;
 
 	/** 変更対象のメールテンプレートID。 */
 	private String mailTemplateId = null;
@@ -83,6 +86,9 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	/** 説明 テキストボックス。 */
 	private Text textDescription = null;
 
+	/** オーナーロールID用テキスト */
+	private RoleIdListComposite m_ownerRoleId = null;
+
 	/** 件名 スタイルテキストコンポジット。 */
 	private TextWithParameterComposite textSubject = null;
 
@@ -96,6 +102,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	 */
 	public MailTemplateCreateDialog(Shell parent) {
 		super(parent);
+		this.mode = PropertyDefineConstant.MODE_ADD;
 	}
 
 	/**
@@ -103,13 +110,13 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param mailTemplateId 変更するメールテンプレート情報のメールテンプレートID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param dataOperationType データ処理タイプ
 	 */
-	public MailTemplateCreateDialog(Shell parent, String mailTemplateId, boolean referenceFlg) {
+	public MailTemplateCreateDialog(Shell parent, String mailTemplateId, int mode) {
 		super(parent);
 
 		this.mailTemplateId = mailTemplateId;
-		this.referenceFlg = referenceFlg;
+		this.mode = mode;
 	}
 
 	/**
@@ -157,7 +164,8 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textMailTemplateId.setLayoutData(gridData);
-		if(this.mailTemplateId != null && !"".equals(this.mailTemplateId.trim())){
+		if(this.mode == PropertyDefineConstant.MODE_SHOW
+				|| this.mode == PropertyDefineConstant.MODE_MODIFY){
 			this.textMailTemplateId.setEnabled(false);
 		}
 		this.textMailTemplateId.addModifyListener(new ModifyListener(){
@@ -185,13 +193,26 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		this.textDescription.setLayoutData(gridData);
 
-		// 空白
-		label = new Label(parent, SWT.NONE);
+		/*
+		 * オーナーロールID
+		 */
+		Label labelRoleId = new Label(parent, SWT.LEFT);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH;
+		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		labelRoleId.setLayoutData(gridData);
+		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+		if (this.mode == PropertyDefineConstant.MODE_ADD) {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+		} else {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+		}
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		m_ownerRoleId.setLayoutData(gridData);
 
 		/*
 		 * メールテンプレート設定
@@ -346,8 +367,13 @@ public class MailTemplateCreateDialog extends CommonDialog {
 			this.textBody.setText(mailTemplate.getBody());
 		}
 
+		// オーナーロールID取得
+		if (mailTemplate.getOwnerRoleId() != null) {
+			this.m_ownerRoleId.setText(mailTemplate.getOwnerRoleId());
+		}
+
 		// 入力制御
-		if(this.referenceFlg){
+		if(this.mode == PropertyDefineConstant.MODE_SHOW){
 			this.textMailTemplateId.setEnabled(false);
 			this.textDescription.setEnabled(false);
 			this.textSubject.setEnabled(false);
@@ -364,7 +390,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	 * 
 	 * @return メールテンプレート情報
 	 */
-	protected MailTemplateInfo createInputData() {
+	private MailTemplateInfo createInputData() {
 		MailTemplateInfo info = new MailTemplateInfo();
 
 		if (this.textMailTemplateId.getText() != null
@@ -384,6 +410,11 @@ public class MailTemplateCreateDialog extends CommonDialog {
 			info.setBody(this.textBody.getText());
 		}
 
+		//オーナーロールID
+		if (this.m_ownerRoleId.getText().length() > 0) {
+			info.setOwnerRoleId(this.m_ownerRoleId.getText());
+		}
+
 		return info;
 	}
 
@@ -419,7 +450,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		if(info != null){
 			String errMessage = "";
 			String[] args = { info.getMailTemplateId() };
-			if(this.mailTemplateId == null){
+			if(this.mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合
 				try {
 					result = MailTemplateEndpointWrapper.addMailTemplate(info);
@@ -450,7 +481,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 							Messages.getString("message.notify.mail.2", args) + errMessage);
 				}
 			}
-			else{
+			else if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
 				// 変更の場合
 				try {
 					result = MailTemplateEndpointWrapper.modifyMailTemplate(info);
@@ -512,7 +543,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	@Override
 	protected void createButtonsForButtonBar(Composite parent) {
 
-		if(!this.referenceFlg){
+		if(this.mode != PropertyDefineConstant.MODE_SHOW){
 			super.createButtonsForButtonBar(parent);
 		}
 		else{
