@@ -68,10 +68,10 @@ import com.clustercontrol.performance.view.PerformanceGraphView;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collector.CollectedDataSet;
+import com.clustercontrol.ws.collector.CollectedDataInfo;
 import com.clustercontrol.ws.collector.CollectorItemInfo;
 import com.clustercontrol.ws.collector.CollectorItemParentInfo;
 import com.clustercontrol.ws.collector.PerformanceDataSettings;
-import com.clustercontrol.ws.monitor.CollectedDataInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -266,7 +266,7 @@ public class PerformanceGraphComposite extends Composite {
 					}
 					displayItem.select(0);
 					displayItem.setEnabled(false);
-					
+
 				}
 				else{
 					displayItem.setEnabled(true);
@@ -817,11 +817,11 @@ public class PerformanceGraphComposite extends Composite {
 		////
 		ChartFactory.setChartTheme(StandardChartTheme.createLegacyTheme());
 		jfreeChart =
-			ChartFactory.createTimeSeriesChart("", // タイトルはここで未設定
-					com.clustercontrol.performance.util.Messages.getString("TIME"),
-					performanceDataSettings.getMeasure(),
-					timeSeriesCollection,
-					true, true, false);
+				ChartFactory.createTimeSeriesChart("", // タイトルはここで未設定
+						com.clustercontrol.performance.util.Messages.getString("TIME"),
+						performanceDataSettings.getMeasure(),
+						timeSeriesCollection,
+						true, true, false);
 		chartComposite.setChart(jfreeChart);
 
 		////
@@ -856,9 +856,9 @@ public class PerformanceGraphComposite extends Composite {
 		////
 		if((HinemosModuleConstant.MONITOR_PERFORMANCE).equals(performanceDataSettings.getMonitorTypeId())){
 			boolean rangeFixed =
-				CollectorItemCodeFactory.isRangeFixed(
-						performanceDataSettings.getTargetItemCode(),
-						targetGraphType);
+					CollectorItemCodeFactory.isRangeFixed(
+							performanceDataSettings.getTargetItemCode(),
+							targetGraphType);
 
 			if (rangeFixed) {
 				ValueAxis valueaxis = jfreeChart.getXYPlot().getRangeAxis();
@@ -959,7 +959,7 @@ public class PerformanceGraphComposite extends Composite {
 					Messages.getString("message.performance.2", args));
 			return;
 		}
-		
+
 		List<FacilityTreeItem> children = treeItem.getChildren();
 
 		for(int i = 0; i < children.size(); i++){
@@ -1180,11 +1180,11 @@ public class PerformanceGraphComposite extends Composite {
 		// 収集データの取得
 		////
 		CollectedDataSet dataSet =
-			new RecordController().getRecordCollectedData(
-					targetConditionFacilityIdList,
-					targetConditionItemList,
-					targetConditionStartDate,
-					targetConditionEndDate);
+				new RecordController().getRecordCollectedData(
+						targetConditionFacilityIdList,
+						targetConditionItemList,
+						targetConditionStartDate,
+						targetConditionEndDate);
 
 		// 性能データの取得に失敗した場合はエラーダイアログを表示
 		if (dataSet == null) {
