@@ -24,29 +24,28 @@ import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
 import java.sql.Timestamp;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
-
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
+import java.util.List;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.commons.util.ConnectionManager;
+import com.clustercontrol.accesscontrol.session.AccessControllerBean;
 import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 import com.clustercontrol.performance.bean.CollectorItemParentInfo;
 import com.clustercontrol.performance.bean.PerformanceDataSettings;
-import com.clustercontrol.performance.ejb.session.CollectorControllerUtil;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.performance.model.CalculatedDataEntity;
+import com.clustercontrol.performance.model.CalculatedDataEntityPK;
+import com.clustercontrol.performance.session.CollectorControllerBean;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -57,7 +56,7 @@ import com.clustercontrol.util.Messages;
  */
 public class ExportCollectedDataFile {
 	private static Log m_log = LogFactory
-	.getLog(ExportCollectedDataFile.class);
+			.getLog(ExportCollectedDataFile.class);
 
 	public static String exportDirectory = null;
 	private static String exportEncode = null;
@@ -79,7 +78,7 @@ public class ExportCollectedDataFile {
 		try {
 			exportFetchSize = Integer.valueOf(exportFetchSizeStr);
 		} catch (NumberFormatException e) {
-			m_log.warn("performance.export.fetchsize is not number format");
+			m_log.info("static() performance.export.fetchsize is not number format");
 			exportFetchSize = 1000;
 		}
 
@@ -109,8 +108,9 @@ public class ExportCollectedDataFile {
 			String monitorId,
 			String facilityId,
 			boolean header,
-			boolean archive)
-			throws HinemosUnknown {
+			boolean archive,
+			String userId)
+					throws HinemosUnknown {
 		m_log.debug("create() monitorId = " + monitorId + ", facilityId = "
 				+ facilityId + ", header = " + header + ", archive");
 
@@ -127,13 +127,16 @@ public class ExportCollectedDataFile {
 
 		ArrayList<String> targetFileNameList = new ArrayList<String>();
 		try {
-
+			MonitorInfoEntity entity = com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK_NONE(monitorId);
 			ArrayList<String> targetFacilityIdList
-			= RepositoryControllerUtil.getLocalHome().create().getExecTargetFacilityIdList(facilityId);
+			= new RepositoryControllerBean().getExecTargetFacilityIdList(facilityId, null);
 
 			if(targetFacilityIdList == null || targetFacilityIdList.size() == 0){
 				String[] args = { facilityId };
-				throw new HinemosUnknown(Messages.getString("message.performance.3", args));
+				HinemosUnknown e = new HinemosUnknown(Messages.getString("message.performance.3", args));
+				m_log.info("create() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
 			}
 
 			// 出力ファイル名を設定
@@ -147,14 +150,14 @@ public class ExportCollectedDataFile {
 
 			// 出力ファイル作成スレッドを実行して抜ける
 			ExportCollectedDataFile exdf = new ExportCollectedDataFile();
-			CreatePerfFileTask task = exdf.new CreatePerfFileTask(monitorId, facilityId, targetFacilityIdList, header, archive, fileId);
+			CreatePerfFileTask task = exdf.new CreatePerfFileTask(monitorId, facilityId, targetFacilityIdList, header, archive, fileId, userId);
 			Thread thread = new Thread(task);
 			thread.start();
 
-		} catch (NamingException e) {
-			m_log.warn("create()", e);
-		} catch (CreateException e) {
-			m_log.warn("create()", e);
+		} catch (HinemosUnknown e) {
+		} catch (Exception e) {
+			m_log.warn("create() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 
 		// for debug
@@ -175,7 +178,7 @@ public class ExportCollectedDataFile {
 	 * @param extension
 	 * @return
 	 */
-	protected static String createFileName(String monitorId, String targetFacilityId, String fileId, String extension){
+	private static String createFileName(String monitorId, String targetFacilityId, String fileId, String extension){
 		return monitorId + "_" + targetFacilityId + "_" + fileId + "." + extension;
 	}
 
@@ -199,11 +202,15 @@ public class ExportCollectedDataFile {
 
 				pw.close();
 			}else{
-				throw new HinemosUnknown("writeEmptyDataFile() filepath = "
+				m_log.info("writeEmptyDataFile() filepath = "
 						+ filepath + " write error");
+				throw new HinemosUnknown("filepath = " + filepath + " write error");
 			}
 		}catch(IOException e){
-			throw new HinemosUnknown("writeEmptyDataFile() filepath = "
+			m_log.warn("writeEmptyDataFile() filepath = "
+					+ filepath + " write error : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			throw new HinemosUnknown("filepath = "
 					+ filepath + " write error", e);
 		}
 	}
@@ -218,7 +225,7 @@ public class ExportCollectedDataFile {
 	 * @throws HinemosUnknown
 	 */
 	private static void writeFile(String monitorId, String facilityId, String filepath,
-			PerformanceDataSettings dataSettings) throws HinemosUnknown{
+			PerformanceDataSettings dataSettings){
 		m_log.debug("writeFile() monitorId = " + monitorId + ", facilityId = " + facilityId + ", filepath = " + filepath);
 
 		PrintWriter pw = null;
@@ -235,85 +242,65 @@ public class ExportCollectedDataFile {
 				nans[i] = false;
 			}
 
-			Connection conn = null;
-			PreparedStatement stmt = null;
-			ResultSet res = null;
 			long lastDate = 0;
+			JpaTransactionManager jtm = null;
 
 			try{
-				conn = ConnectionManager.getConnectionManager().getConnection();
-				conn.setAutoCommit(false);
-				m_log.debug("writeFile() conn is " + conn.getClass().getCanonicalName());
-
-				// SQL文の作成
-				String sql = "SELECT date_time, item_code, display_name, value FROM cc_calculated_data WHERE collectorid = ? AND facilityid = ? AND date_time <= ? ORDER BY 1,2,3,4";
-
-				// SQL文発行準備
-				stmt = conn.prepareStatement(sql);
-
-				stmt.setString(1, monitorId);
-				stmt.setString(2, facilityId);
-				stmt.setTimestamp(3, new Timestamp(dataSettings.getLatestDate()));
-				stmt.setFetchSize(exportFetchSize);
+				jtm = new JpaTransactionManager();
+				jtm.begin();
+				List<CalculatedDataEntity> calculatedDataEntityList
+				= QueryUtil.getCalculatedDataByCollectoridFacilityidDateTime(monitorId,
+						facilityId,
+						new Timestamp(dataSettings.getLatestDate()),
+						exportFetchSize);
 				m_log.debug("writeFile() set statement fetchsize = " + exportFetchSize);
 
-				m_log.debug("sql : " + sql);
-				res = stmt.executeQuery();
-
 				// 配列への性能値の格納
-				while (res.next()) {
+				for(CalculatedDataEntity calculatedDataEntity : calculatedDataEntityList) {
 
 					// ファイル書き込み
 
+					CalculatedDataEntityPK pk = calculatedDataEntity.getId();
 					// for debug
-					if(m_log.isDebugEnabled()){
-						m_log.debug("writeFile() date = " + lastDate + ", itemCode = " + res.getString("ITEM_CODE") + ", displayName = " + res.getString("DISPLAY_NAME"));
-					}
+					m_log.debug("writeFile() date = " + lastDate
+							+ ", itemCode = " + pk.getItemCode()
+							+ ", displayName = " + pk.getDisplayName());
 
 					// 収集時刻が変わった契機で1行writeする。
-					if(lastDate != 0 && lastDate != res.getTimestamp("DATE_TIME").getTime()){
+					if(lastDate != 0 && lastDate != pk.getDateTime().getTime()){
 						m_log.debug("writeFile() lastDate = " + lastDate);
-
 						// write
 						StringBuffer bs = new StringBuffer((new Date(lastDate)).toString());
 						for(int i = 0; i < columnNum; i++){
-							if(nans[i])
-								if(values[i] == null)
+							if(nans[i]) {
+								if(values[i] == null) {
 									bs.append("," + NOT_A_NUMBER);
-								else
+								} else {
 									bs.append("," + values[i]);
-							else
+								}
+							} else {
 								bs.append("," + NOT_EXISTS);
+							}
 						}
-						if(m_log.isDebugEnabled()){
-							m_log.debug("writeFile() write line = " + bs.toString());
-						}
+						m_log.debug("writeFile() write line = " + bs.toString());
 						pw.print(bs.toString());
 						pw.print(exportLineSeparator);
 						pw.flush();
-
 						// reset
 						for(int i = 0; i < columnNum; i++){
 							values[i] = null;
 							nans[i] = false;
 						}
 					}
-					lastDate = res.getTimestamp("DATE_TIME").getTime();
+					lastDate = pk.getDateTime().getTime();
 
 					// dataInfoがどの列のデータかを判断し、配列にセットする
 					for (int i = 0; i < itemInfoList.size(); i++) {
-
 						// i列目のデータか
-						if(res.getString("ITEM_CODE") != null && res.getString("ITEM_CODE").equals(itemInfoList.get(i).getItemCode()) &&
-								res.getString("DISPLAY_NAME") != null && res.getString("DISPLAY_NAME").equals(itemInfoList.get(i).getDisplayName())){
-
-							if(res.getObject("VALUE") == null){
-								values[i] = null;
-							}else{
-								values[i] = res.getDouble("VALUE");
-							}
+						if(pk.getItemCode() != null && pk.getItemCode().equals(itemInfoList.get(i).getItemCode()) &&
+								pk.getDisplayName() != null && pk.getDisplayName().equals(itemInfoList.get(i).getDisplayName())){
+							values[i] = calculatedDataEntity.getValue();
 							nans[i] = true;
-
 							break;
 						}
 					}
@@ -323,56 +310,38 @@ public class ExportCollectedDataFile {
 				// 最後のデータをフラッシュする
 				if(dataSettings.getLatestDate().longValue() == lastDate){
 					m_log.debug("writeFile() write last data : lastDate = " + lastDate);
-
 					// write
 					StringBuffer bs = new StringBuffer((new Date(lastDate)).toString());
 					for(int i = 0; i < columnNum; i++){
-						if(nans[i])
-							if(values[i] == null)
+						if(nans[i]) {
+							if(values[i] == null) {
 								bs.append("," + NOT_A_NUMBER);
-							else
+							} else {
 								bs.append("," + values[i]);
-						else
+							}
+						} else {
 							bs.append("," + NOT_EXISTS);
+						}
 					}
-					if(m_log.isDebugEnabled()){
-						m_log.debug("writeFile() write line = " + bs.toString());
-					}
+					m_log.debug("writeFile() write line = " + bs.toString());
 					pw.print(bs.toString());
 					pw.print(exportLineSeparator);
 					pw.flush();
 				}
-
-			} catch (SQLException e) {
-				m_log.warn("write csv file by SQLException monitorId = " + monitorId + ", facilityId = " + facilityId + ", filepath = " + filepath, e);
+				jtm.commit();
+			} catch (Exception e) {
+				m_log.warn("writeFile() write csv file by SQLException monitorId = " + monitorId + ", facilityId = " + facilityId + ", filepath = " + filepath, e);
+				jtm.rollback();
 			} finally {
-				if(res != null){
-					try{
-						res.close();
-					} catch (SQLException e) {
-						m_log.debug("writeFile()", e);
-					}
-				}
-				if(stmt != null){
-					try{
-						stmt.close();
-					} catch (SQLException e) {
-						m_log.debug("writeFile()", e);
-					}
-				}
-				if(conn != null){
-					try{
-						conn.close();
-					} catch (SQLException e) {
-						m_log.debug("writeFile()", e);
-					}
-				}
+				jtm.close();
 			}
 
 		} catch (UnsupportedEncodingException e) {
-			m_log.warn("Unsupported Encoding : exportEncode = " + exportEncode + ". Please modify performance.export.encode");
+			m_log.warn("writeFile() Unsupported Encoding : exportEncode = " + exportEncode + ". Please modify performance.export.encode : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		} catch (FileNotFoundException e) {
-			m_log.warn("File does not exists! filepath = " + filepath);
+			m_log.warn("File does not exists! filepath = " + filepath + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		} finally {
 			if(pw != null){
 				pw.close();
@@ -390,7 +359,7 @@ public class ExportCollectedDataFile {
 	private static void writeHeader(String filepath, String monitorId,
 			String facilityId, long startDate, long lastDate,
 			PerformanceDataSettings dataSettings)
-	throws HinemosUnknown {
+					throws HinemosUnknown {
 
 		PrintWriter pw = null;
 		try {
@@ -433,14 +402,12 @@ public class ExportCollectedDataFile {
 				pw.print(exportLineSeparator); // 改行
 
 			} else {
-				throw new HinemosUnknown("writeHeader() filepath = "
-						+ filepath + " write error");
+				m_log.info("writeHeader() filepath = " + filepath + " write error");
+				throw new HinemosUnknown("filepath = " + filepath + " write error");
 			}
 		} catch (IOException e) {
-
-			m_log.error(
-					"writeHeader() filepath = " + filepath + " is io error", e);
-			throw new HinemosUnknown("writeHeader() filepath = "
+			m_log.warn("writeHeader() filepath = " + filepath + " is io error", e);
+			throw new HinemosUnknown("filepath = "
 					+ filepath + " is io error", e);
 
 		} finally {
@@ -456,7 +423,7 @@ public class ExportCollectedDataFile {
 	 * @param filePathList
 	 */
 	public static void deleteFile(ArrayList<String> fileNameList)
-	throws HinemosUnknown {
+			throws HinemosUnknown {
 		m_log.debug("deleteFile()");
 
 		for (String fileName : fileNameList) {
@@ -483,8 +450,7 @@ public class ExportCollectedDataFile {
 	 * 
 	 * @param filePathList
 	 */
-	private static void deleteFilePath(ArrayList<String> filePathList)
-	throws HinemosUnknown {
+	private static void deleteFilePath(ArrayList<String> filePathList) {
 		m_log.debug("deleteFilePath()");
 
 		for (String filePath : filePathList) {
@@ -545,7 +511,7 @@ public class ExportCollectedDataFile {
 				return true;
 			}
 		} else {
-			m_log.info("Crate Performance Export File. file = " + file.getPath());
+			m_log.info("checkBeforeWritefile() Crate Performance Export File. file = " + file.getPath());
 			return file.createNewFile();
 		}
 		return false;
@@ -557,7 +523,7 @@ public class ExportCollectedDataFile {
 	 * @author hinemos
 	 *
 	 */
-	protected class CreatePerfFileTask implements Runnable {
+	private class CreatePerfFileTask implements Runnable {
 
 		private String m_monitorId = "";
 		private String m_targetFacilityId = "";
@@ -565,6 +531,7 @@ public class ExportCollectedDataFile {
 		private boolean m_header = false;
 		private boolean m_archive = false;
 		private String m_fileId = "";
+		private String m_userId = "";
 
 		/**
 		 * デフォルトコンストラクタ
@@ -575,14 +542,16 @@ public class ExportCollectedDataFile {
 		 * @param header
 		 * @param archive
 		 * @param fileId
+		 * @param userId
 		 */
-		protected CreatePerfFileTask(
+		private CreatePerfFileTask(
 				String monitorId,
 				String targetFacilityId,
 				ArrayList<String> facilityIdList,
 				boolean header,
 				boolean archive,
-				String fileId) {
+				String fileId,
+				String userId) {
 
 			this.m_monitorId = monitorId;
 			this.m_targetFacilityId = targetFacilityId;
@@ -590,6 +559,7 @@ public class ExportCollectedDataFile {
 			this.m_header = header;
 			this.m_archive = archive;
 			this.m_fileId = fileId;
+			this.m_userId = userId;
 
 			m_log.debug("CreatePerfFileTask Create : monitorId = " + monitorId + ", targetFacilityId = " + targetFacilityId + ", header = " + header + ", archive = " + archive + ", fileId");
 		}
@@ -605,8 +575,13 @@ public class ExportCollectedDataFile {
 			ArrayList<String> createFilePathList = new ArrayList<String>();
 
 			try {
-				PerformanceDataSettings dataSettings = CollectorControllerUtil
-				.getLocalHome().create().getPerformanceGraphInfo(m_monitorId);
+				// 新たなスレッドとして開始される場合は、ユーザ情報が格納されていないため、ユーザ情報を改めて格納
+				HinemosSessionContext.instance().setProperty(HinemosSessionContext.LOGIN_USER_ID, m_userId);
+				HinemosSessionContext.instance().setProperty(HinemosSessionContext.IS_ADMINISTRATOR, 
+						new AccessControllerBean().isAdministrator());
+				
+				PerformanceDataSettings dataSettings
+				= new CollectorControllerBean().getPerformanceGraphInfo(m_monitorId);
 
 				////
 				// CSVファイルの作成
@@ -675,27 +650,20 @@ public class ExportCollectedDataFile {
 					renameFile(createTmpArchiveFilePath, createArchiveFilePath);
 				}
 
-			} catch (NamingException e) {
-				m_log.warn("run()",e);
-				success = false;
-			} catch (CreateException e) {
-				m_log.warn("run()",e);
-				success = false;
 			} catch (HinemosUnknown e) {
-				m_log.warn("run()",e);
+				m_log.info("run() " + e.getMessage(), e);
+				success = false;
+			} catch (Exception e) {
+				m_log.info("run() " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				success = false;
 			} finally {
 				if(!success){
-					m_log.debug("run() : Since processing went wrong, a file is deleted.");
-					try{
-						deleteFilePath(createFilePathList);
-					} catch (HinemosUnknown e) {
-						m_log.warn("run()",e);
-					}
+					m_log.debug("ExportCollectedDataFile.run() : Since processing went wrong, a file is deleted.");
+					deleteFilePath(createFilePathList);
 				}
 			}
 
-			m_log.info("CreatePerfFileTask finish!");
+			m_log.info("run() CreatePerfFileTask finish!");
 		}
 
 	}
