@@ -110,6 +110,9 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
 	private ArrayList<String> m_lastPollingOids;
 
+	// ファイルシステムにLabelが含まれているときに削除する。（Windows用）
+	private static boolean deleteLabel = true;
+
 	/**
 	 * アプリケーションスレッドがポーリング完了を待つためのラッチ。
 	 * アプリケーションからの呼び出し箇所では、joeSNMPに実行を依頼した後、
@@ -118,6 +121,15 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 	 */
 	private final CountDownLatch latchPollingEnd = new CountDownLatch(1);
 
+	static {
+		try {
+			deleteLabel = Boolean.parseBoolean(HinemosProperties.getProperty("monitor.resource.delete.label", "true"));
+		} catch (Exception e) {
+			m_log.info("SnmpPollerImpl " + e.getMessage());
+		}
+		m_log.info("SnmpPollerImpl deleteLabel=" + deleteLabel);
+	}
+
 	enum PollerStatus {
 		/** まだこのポーラーが使用されていない状態<br>
 		 * POLLING/INTERNALにのみ状態遷移する。 */
@@ -163,7 +175,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 				maxRepetitions = Integer.parseInt(str);
 			}
 		} catch (Exception e) {
-			m_log.warn(nkey + " is not available. " + e.getMessage());
+			m_log.warn(nkey + " is not available. " + e.getMessage(), e);
 		}
 		String mkey = "poller.snmp.bulk.maxrepetitions";
 		try {
@@ -172,7 +184,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 				maxRepetitions = Integer.parseInt(str);
 			}
 		} catch (Exception e) {
-			m_log.warn(mkey + " is not available. " + e.getMessage());
+			m_log.warn(mkey + " is not available. " + e.getMessage(), e);
 		}
 	}
 
@@ -273,7 +285,8 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 		try {
 			peer = new SnmpPeer(InetAddress.getByName(ipAddress));
 		} catch (UnknownHostException e) {
-			m_log.error("polling() error  :" + ipAddress.toString(), e);
+			m_log.info("polling() error  " + ipAddress.toString() + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			return m_dataTable;
 		}
 		if (port < 0){
@@ -318,7 +331,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 		try {
 			session = new SnmpSession(peer);
 		} catch (SocketException e) {
-			m_log.error("polling() warning  :" + ipAddress.toString()
+			m_log.info("polling() warning  :" + ipAddress.toString()
 					+ " SocketException creating the SNMP session");
 			setPollerStatus(PollerStatus.INTERNAL);
 			return m_dataTable;
@@ -378,7 +391,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 			latchPollingEnd.await();
 
 		} catch (InterruptedException e) {
-			m_log.error("polling() warning :" + ipAddress.toString()
+			m_log.info("polling() warning :" + ipAddress.toString()
 					+ " polling failed at InterruptedException");
 			setPollerStatus(PollerStatus.INTERNAL);
 		} finally {
@@ -401,13 +414,13 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 				 * Joe-SNMPで不具合が修正されたら削除すること
 				 */
 				m_log.warn("polling():" + m_ipAddress
-						+ " Session close failed");
+						+ " Session close failed", e);
 			}
 		}
 
 		// リトライ回数が多い場合は出力する
 		if(m_indexCheckRetryCountTotal >= 100){
-			m_log.warn("polling():" + m_ipAddress +
+			m_log.info("polling():" + m_ipAddress +
 					" too many retries. count : " + m_indexCheckRetryCountTotal);
 		}
 
@@ -435,14 +448,14 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 			if (pdu instanceof SnmpPduRequest) {
 				req = (SnmpPduRequest) pdu;
 			} else {
-				m_log.error("polling() error :" + session.toString()
+				m_log.info("polling() error :" + session.toString()
 						+ " Received non-request pdu");
 				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
 
 			if (pdu.getCommand() != SnmpPduPacket.RESPONSE) {
-				m_log.error("polling() error :" + session.toString()
+				m_log.info("polling() error :" + session.toString()
 						+ "  Received non-response command "
 						+ pdu.getCommand());
 				setPollerStatus(PollerStatus.INTERNAL);
@@ -451,11 +464,11 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 
 			if (req.getErrorStatus() != 0) {
 				String message = "polling() error :" + session.toString() +
-				", ErrorStatus=" + req.getErrorStatus();
+						", ErrorStatus=" + req.getErrorStatus();
 				if (req.getLength() != 0) {
 					message += ", oid=" + req.getVarBindAt(0).getName();
 				}
-				m_log.error(message);
+				m_log.info(message);
 				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
@@ -518,7 +531,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 				// 停止条件のOIDにマッチした場合は終了
 				if (var.getValue().typeId() == SnmpEndOfMibView.ASNTYPE
 						|| ((m_stopOids.get(i % oidSize) != null &&
-								m_stopOids.get(i % oidSize).compare(var.getName()) < 0))) {
+						m_stopOids.get(i % oidSize).compare(var.getName()) < 0))) {
 
 					// 該当OIDの収集を終了します
 					if (m_log.isTraceEnabled()) {
@@ -678,13 +691,21 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 							value = new String(stringBytes, 0 , stringLen);
 						}
 
+						// Windowsのファイルシステム名からラベルを削除する。
+						// C:\ Label:  Serial Number 80f3e65c
+						// ↓
+						// C:\
+						if (deleteLabel && oidString.startsWith(SearchNodeProperties.DEFAULT_OID_FILESYSTEM_NAME)) {
+							value = value.replaceAll(" Label:  Serial Number .*", "");
+						}
+
 						if(m_log.isTraceEnabled()){
 							m_log.trace("SnmpOctetString getValue string = " + value);
 						}
 
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, value)
-							);
+									);
 
 							m_log.trace("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) +
@@ -866,7 +887,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 								// 最大のインデックスのものがリトライによって収集されるように
 								// maxIndex-lをインデックスに設定する
 								String nextOid = lastOid.substring(0, lastOid.lastIndexOf(".") + 1)
-								+ (maxIndex - 1);
+										+ (maxIndex - 1);
 
 								nextStartOids.add(m_startOids.get(i));
 								nextStopOids.add(m_stopOids.get(i));
@@ -879,7 +900,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(index not match). " + m_ipAddress
+							m_log.info("too many retries(index not match). " + m_ipAddress
 									+ " count:" + m_indexCheckDiffIndexRetryCount);
 
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
@@ -923,7 +944,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(VarBind size not match). " + m_ipAddress
+							m_log.info("too many retries(VarBind size not match). " + m_ipAddress
 									+ " count:" + m_indexCheckVarBindSizeRetryCount);
 
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
@@ -951,8 +972,8 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 				return;
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
-			m_log.error("InternalError ", e);
-
+			m_log.warn("snmpReceivedPdu() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// ステータスをインターナルエラーとして、ポーリング完了待ちスレッドに通知する
 			setPollerStatus(PollerStatus.INTERNAL);
 		}
@@ -966,8 +987,8 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 	@Override
 	public void snmpInternalError(SnmpSession session, int err, SnmpSyntax pdu) {
 		String message = "InternalError. The error code is " + err + ". IP:"
-		+ m_ipAddress + " OID:" + m_oidText[0];
-		m_log.error("snmpInternalError():" + session.toString() + " " + message);
+				+ m_ipAddress + " OID:" + m_oidText[0];
+		m_log.info("snmpInternalError():" + session.toString() + " " + message);
 
 		// ステータスをインターナルエラーとし、ポーリング完了待ちスレッドに通知する
 		setPollerStatus(PollerStatus.INTERNAL);
@@ -987,7 +1008,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 		SnmpVarBind[] bind = ((SnmpPduRequest) pdu).toVarBindArray();
 		String ipAddress = session.getPeer().getPeer().toString();
 		String message = "Polling failed at TimeoutError." + " IP:" + ipAddress
-		+ " OID:" + bind[0].getName();
+				+ " OID:" + bind[0].getName();
 
 		// より詳細なメッセージを作成
 		String addMessage = "";
@@ -998,7 +1019,7 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 			message = message + addMessage;
 		}
 
-		m_log.warn(message);
+		m_log.info(message);
 
 		// ステータスをTIMEOUTとし、ポーリング完了待ちスレッドに通知する
 		setPollerStatus(PollerStatus.TIMEOUT);
@@ -1118,12 +1139,10 @@ public class SnmpBulkPollerImpl implements SnmpHandler {
 
 			// 取得値の一覧を表示
 			Iterator<TableEntry> itr = ts.iterator();
-			int i = 0;
 			while(itr.hasNext()){
 				TableEntry entry = itr.next();
 				m_log.info(entry);
 				// System.out.println("tableEntry " + i + "," +  entry);
-				i++;
 			}
 			System.out.println("ts.size()=" + ts.size());
 			System.out.println("time = " + (end - start) + "ms " + poller.getClass().getSimpleName());
