@@ -43,6 +43,8 @@ import org.opennms.protocols.snmp.SnmpSyntax;
 import org.opennms.protocols.snmp.SnmpUInt32;
 import org.opennms.protocols.snmp.SnmpVarBind;
 
+import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.nodemap.util.SearchConnectionProperties;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.repository.util.SearchNodeProperties;
 import com.clustercontrol.sharedtable.DataTable;
@@ -108,6 +110,11 @@ public class SnmpPollerImpl implements SnmpHandler {
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
 	private ArrayList<String> m_lastPollingOids;
 
+	private boolean m_errorIgnoreFlg = false;
+
+	// ファイルシステムにLabelが含まれているときに削除する。（Windows用）
+	private static boolean deleteLabel = true;
+
 	/**
 	 * アプリケーションスレッドがポーリング完了を待つためのラッチ。
 	 * アプリケーションからの呼び出し箇所では、joeSNMPに実行を依頼した後、
@@ -116,6 +123,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 */
 	private final CountDownLatch latchPollingEnd = new CountDownLatch(1);
 
+	static {
+		try {
+			deleteLabel = Boolean.parseBoolean(HinemosProperties.getProperty("monitor.resource.delete.label", "true"));
+		} catch (Exception e) {
+			m_log.info("SnmpPollerImpl " + e.getMessage());
+		}
+		m_log.info("SnmpPollerImpl deleteLabel=" + deleteLabel);
+	}
+
 	enum PollerStatus {
 		/** まだこのポーラーが使用されていない状態<br>
 		 * POLLING/INTERNALにのみ状態遷移する。 */
@@ -199,6 +215,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 		m_indexCheckVarBindSizeRetryCount = 0;
 		m_indexCheckRetryCountTotal = 0;
 		m_indexCheckLastIndexRetryCount = 0;
+
 	}
 
 	/**
@@ -224,6 +241,34 @@ public class SnmpPollerImpl implements SnmpHandler {
 			int timeout,
 			List<String> oidList,
 			boolean indexCheckFlg) {
+		return polling(ipAddress, port, version, community, retries, timeout, oidList, indexCheckFlg, false);
+	}
+
+	/**
+	 * メインルーチン
+	 * IPアドレスと　DataTableを受け取り、
+	 * ポーリングした結果をDataTableに代入する
+	 * 
+	 * @param ipAddress IPアドレス
+	 * @param port ポート番号
+	 * @param version バージョン（0:SNMP V1 protocol, 1:SNMP V2 protocol）
+	 * @param community コミュニティ
+	 * @param retries １回のポーリングでのリトライ回数
+	 * @param timeout ポーリングのタイムアウト
+	 * @param oidList 対象OIDのリスト
+	 * @param indexCheckFlg ポーリング結果のインデックスが揃っているかのチェック
+	 * @param errorIgnoreFlg ポーリング時のエラーを無視するかのチェック
+	 */
+	public DataTable polling(
+			String ipAddress,
+			int port,
+			int version,
+			String community,
+			int retries,
+			int timeout,
+			List<String> oidList,
+			boolean indexCheckFlg,
+			boolean errorIgnoreFlg) {
 		// クラス変数を初期化
 		init();
 
@@ -232,13 +277,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 		m_ipAddress = ipAddress;
 		m_indexCheckFlg = indexCheckFlg;
+		m_errorIgnoreFlg = errorIgnoreFlg;
 
 		// SnmpPeer の定義
 		SnmpPeer peer;
 		try {
 			peer = new SnmpPeer(InetAddress.getByName(ipAddress));
 		} catch (UnknownHostException e) {
-			m_log.error("polling() error  :" + ipAddress.toString(), e);
+			m_log.info("polling() error  :" + ipAddress.toString() + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			return m_dataTable;
 		}
 		if (port < 0){
@@ -276,6 +323,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			m_log.trace("Retries         : " + peer.getRetries());
 			m_log.trace("Timeout         : " + peer.getTimeout());
 			m_log.trace("IndexCheckFlg   : " + indexCheckFlg);
+			m_log.trace("ErrorIgnoreFlg   : " + errorIgnoreFlg);
 		}
 
 		// sessionを生成
@@ -283,7 +331,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 		try {
 			session = new SnmpSession(peer);
 		} catch (SocketException e) {
-			m_log.error("polling() warning  :" + ipAddress.toString()
+			m_log.info("polling() warning  :" + ipAddress.toString()
 					+ " SocketException creating the SNMP session");
 			setPollerStatus(PollerStatus.INTERNAL);
 			return m_dataTable;
@@ -343,7 +391,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			latchPollingEnd.await();
 
 		} catch (InterruptedException e) {
-			m_log.error("polling() warning :" + ipAddress.toString()
+			m_log.info("polling() warning :" + ipAddress.toString()
 					+ " polling failed at InterruptedException");
 			setPollerStatus(PollerStatus.INTERNAL);
 		} finally {
@@ -353,7 +401,11 @@ public class SnmpPollerImpl implements SnmpHandler {
 				// テーブルに含まれているデータを全て削除する。
 				synchronized (lockModifyStatus) {
 					if (getPollerStatus() != PollerStatus.COMPLETE) {
-						m_dataTable.clear();
+						if(!m_errorIgnoreFlg){
+							m_dataTable.clear();
+						}else{
+							m_log.debug("polling() " + ipAddress.toString() + " error code " + getPollerStatus() + " is ignored");
+						}
 					}
 				}
 
@@ -366,13 +418,13 @@ public class SnmpPollerImpl implements SnmpHandler {
 				 * Joe-SNMPで不具合が修正されたら削除すること
 				 */
 				m_log.warn("polling():" + m_ipAddress
-						+ " Session close failed");
+						+ " Session close failed", e);
 			}
 		}
 
 		// リトライ回数が多い場合は出力する
 		if(m_indexCheckRetryCountTotal >= 100){
-			m_log.warn("polling():" + m_ipAddress +
+			m_log.info("polling():" + m_ipAddress +
 					" too many retries. count : " + m_indexCheckRetryCountTotal);
 		}
 
@@ -400,14 +452,14 @@ public class SnmpPollerImpl implements SnmpHandler {
 			if (pdu instanceof SnmpPduRequest) {
 				req = (SnmpPduRequest) pdu;
 			} else {
-				m_log.error("polling() error :" + session.toString()
+				m_log.info("polling() error :" + session.toString()
 						+ " Received non-request pdu");
 				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
 
 			if (pdu.getCommand() != SnmpPduPacket.RESPONSE) {
-				m_log.error("polling() error :" + session.toString()
+				m_log.info("polling() error :" + session.toString()
 						+ "  Received non-response command "
 						+ pdu.getCommand());
 				setPollerStatus(PollerStatus.INTERNAL);
@@ -416,13 +468,17 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 			if (req.getErrorStatus() != 0) {
 				String message = "polling() error :" + session.toString() +
-				", ErrorStatus=" + req.getErrorStatus();
+						", ErrorStatus=" + req.getErrorStatus();
 				if (req.getLength() != 0) {
 					message += ", oid=" + req.getVarBindAt(0).getName();
 				}
-				m_log.error(message);
+				m_log.info(message);
 				setPollerStatus(PollerStatus.INTERNAL);
-				return;
+				if(!m_errorIgnoreFlg){
+					return;
+				}else{
+					m_log.trace("snmpReceivedPdu() error ignored");
+				}
 			}
 
 			// 次の pduを作成
@@ -457,7 +513,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 				// 停止条件のOIDにマッチした場合は終了
 				if (var.getValue().typeId() == SnmpEndOfMibView.ASNTYPE
 						|| ((m_stopOids.get(i) != null &&
-								m_stopOids.get(i).compare(var.getName()) < 0))) {
+						m_stopOids.get(i).compare(var.getName()) < 0))) {
 
 					// 該当OIDの収集を終了します
 					if (m_log.isTraceEnabled()) {
@@ -596,7 +652,10 @@ public class SnmpPollerImpl implements SnmpHandler {
 						byte[] stringBytes = ((SnmpOctetString)var.getValue()).getString();
 						String value = null;
 
-						if (oidString.startsWith(SearchNodeProperties.DEFAULT_OID_NIC_MAC_ADDRESS) && stringBytes.length == 6) {
+						if ((oidString.startsWith(SearchNodeProperties.DEFAULT_OID_NIC_MAC_ADDRESS) ||
+								oidString.startsWith(SearchConnectionProperties.DEFAULT_OID_ARP) ||
+								oidString.startsWith(SearchConnectionProperties.DEFAULT_OID_FDB)) &&
+							stringBytes.length == 6) {
 							// 6 byteのbinaryのOctetString
 							// 00:0A:1F:5F:30 という値として扱う
 							String hex = "";
@@ -617,13 +676,21 @@ public class SnmpPollerImpl implements SnmpHandler {
 							value = new String(stringBytes, 0 , stringLen);
 						}
 
+						// Windowsのファイルシステム名からラベルを削除する。
+						// C:\ Label:  Serial Number 80f3e65c
+						// ↓
+						// C:\
+						if (deleteLabel && oidString.startsWith(SearchNodeProperties.DEFAULT_OID_FILESYSTEM_NAME)) {
+							value = value.replaceAll(" Label:  Serial Number .*", "");
+						}
+
 						if(m_log.isTraceEnabled()){
 							m_log.trace("SnmpOctetString getValue string = " + value);
 						}
 
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, value)
-							);
+									);
 
 							m_log.trace("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) +
@@ -798,7 +865,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 								// 最大のインデックスのものがリトライによって収集されるように
 								// maxIndex-lをインデックスに設定する
 								String nextOid = lastOid.substring(0, lastOid.lastIndexOf(".") + 1)
-								+ (maxIndex - 1);
+										+ (maxIndex - 1);
 
 								nextStartOids.add(m_startOids.get(i));
 								nextStopOids.add(m_stopOids.get(i));
@@ -811,7 +878,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(index not match). " + m_ipAddress
+							m_log.info("too many retries(index not match). " + m_ipAddress
 									+ " count:" + m_indexCheckDiffIndexRetryCount);
 
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
@@ -855,7 +922,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(VarBind size not match). " + m_ipAddress
+							m_log.info("too many retries(VarBind size not match). " + m_ipAddress
 									+ " count:" + m_indexCheckVarBindSizeRetryCount);
 
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
@@ -883,8 +950,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 				return;
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
-			m_log.error("InternalError ", e);
-
+			m_log.warn("snmpReceivedPdu() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// ステータスをインターナルエラーとして、ポーリング完了待ちスレッドに通知する
 			setPollerStatus(PollerStatus.INTERNAL);
 		}
@@ -898,8 +965,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 	@Override
 	public void snmpInternalError(SnmpSession session, int err, SnmpSyntax pdu) {
 		String message = "InternalError. The error code is " + err + ". IP:"
-		+ m_ipAddress + " OID:" + m_oidText[0];
-		m_log.error("snmpInternalError():" + session.toString() + " " + message);
+				+ m_ipAddress + " OID:" + m_oidText[0];
+		m_log.info("snmpInternalError():" + session.toString() + " " + message);
 
 		// ステータスをインターナルエラーとし、ポーリング完了待ちスレッドに通知する
 		setPollerStatus(PollerStatus.INTERNAL);
@@ -919,7 +986,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 		SnmpVarBind[] bind = ((SnmpPduRequest) pdu).toVarBindArray();
 		String ipAddress = session.getPeer().getPeer().toString();
 		String message = "Polling failed at TimeoutError." + " IP:" + ipAddress
-		+ " OID:" + bind[0].getName();
+				+ " OID:" + bind[0].getName();
 
 		// より詳細なメッセージを作成
 		String addMessage = "";
@@ -930,7 +997,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			message = message + addMessage;
 		}
 
-		m_log.warn(message);
+		m_log.info(message);
 
 		// ステータスをTIMEOUTとし、ポーリング完了待ちスレッドに通知する
 		setPollerStatus(PollerStatus.TIMEOUT);
@@ -1034,7 +1101,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 					retries,
 					timeout,
 					oids,
-					indexCheckFlg);
+					indexCheckFlg,
+					true);
 			long end = System.currentTimeMillis();
 
 			Set<String> keyset = dataTable.keySet();
@@ -1054,7 +1122,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			while(itr.hasNext()){
 				TableEntry entry = itr.next();
 				m_log.info(entry);
-				// System.out.println("tableEntry " + i + "," +  entry);
+				System.out.println("tableEntry " + i + "," +  entry);
 				i++;
 			}
 			System.out.println("ts.size()=" + ts.size());
