@@ -17,6 +17,7 @@ package com.clustercontrol.repository.action;
 
 import org.eclipse.jface.dialogs.MessageDialog;
 
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.action.FacilityTree;
 import com.clustercontrol.bean.PluginConstant;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
@@ -43,7 +44,7 @@ public class DeleteNodeProperty {
 			RepositoryEndpointWrapper.deleteNode(facilityId);
 
 			// リポジトリキャッシュの更新
-			FacilityTree.reflesh();
+			LocalSession.doCheck();
 
 			// 成功報告ダイアログを生成
 			MessageDialog.openInformation(
