@@ -29,10 +29,10 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.repository.action.GetAgentListTableDefine;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.repository.AgentStatusInfo;
 import com.clustercontrol.ws.repository.InvalidRole_Exception;
 
@@ -173,6 +173,7 @@ public class AgentListComposite extends Composite {
 			aList.add(node.getFacilityName());
 			aList.add(new Date(node.getStartupTime()));
 			aList.add(new Date(node.getLastLogin()));
+			aList.add(node.getMultiplicity());
 			if (node.isNewFlag()) {
 				aList.add(Messages.getString("done"));
 			} else {
