@@ -16,11 +16,8 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.repository.composite;
 
 import java.util.ArrayList;
-import java.util.List;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -28,14 +25,13 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.repository.action.GetScopeListTableDefine;
 import com.clustercontrol.repository.bean.FacilityConstant;
-import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
+import com.clustercontrol.repository.composite.action.ScopeDoubleClickListener;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
-import com.clustercontrol.ws.repository.InvalidRole_Exception;
 
 /**
  * スコープ登録一覧コンポジットクラスです。
@@ -50,8 +46,8 @@ public class ScopeListComposite extends Composite {
 
 	// ----- instance フィールド ----- //
 
-	protected FacilityTreeItem m_facilityTreeItem = null;
-	protected FacilityTreeItem m_selectFacilityTreeItem = null;
+	private FacilityTreeItem m_facilityTreeItem = null;
+	private FacilityTreeItem m_selectFacilityTreeItem = null;
 
 	/** テーブルビューア */
 	private CommonTableViewer tableViewer = null;
@@ -106,6 +102,9 @@ public class ScopeListComposite extends Composite {
 				GetScopeListTableDefine.SORT_COLUMN_INDEX,GetScopeListTableDefine.SORT_COLUMN_INDEX_SECOND,
 				GetScopeListTableDefine.SORT_ORDER);
 
+		// ダブルクリックリスナの追加
+		this.tableViewer.addDoubleClickListener(new ScopeDoubleClickListener(this));
+
 	}
 
 	/**
@@ -115,46 +114,30 @@ public class ScopeListComposite extends Composite {
 	 *            選択されたFacilityTreeItem
 	 */
 	public void update(FacilityTreeItem item) {
-		List<FacilityInfo> list = null;
+		ArrayList<Object> listInput = new ArrayList<Object>();
 		if (item instanceof FacilityTreeItem) {
 			m_facilityTreeItem = item;
 
-			String facilityId = item.getData().getFacilityId();
 			int type = item.getData().getFacilityType();
-			if (type != FacilityConstant.TYPE_NODE) {
-				try {
-					list = RepositoryEndpointWrapper.getFacilityList(facilityId);
-				} catch (InvalidRole_Exception e) {
-					// アクセス権なしの場合、エラーダイアログを表示する
-					MessageDialog.openInformation(null, Messages.getString("message"),
-							Messages.getString("message.accesscontrol.16"));
-				} catch (Exception e) {
-					m_log.warn("update(), " + e.getMessage(), e);
-					MessageDialog.openError(
-							null,
-							Messages.getString("failed"),
-							Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			if (type != FacilityConstant.TYPE_NODE
+					&& item.getChildren() != null) {
+				for (FacilityTreeItem child : item.getChildren()) {
+					FacilityInfo scope = child.getData();
+					ArrayList<Object> a = new ArrayList<Object>();
+					a.add(scope.getFacilityId());
+					a.add(scope.getFacilityName());
+					a.add(scope.getDescription());
+					a.add(scope.getOwnerRoleId());
+					a.add(scope.getDisplaySortOrder());
+					listInput.add(a);
 				}
 			}
 		}
 
-		if(list == null) {
-			list = new ArrayList<FacilityInfo>();
-		}
-
-		ArrayList<Object> listInput = new ArrayList<Object>();
-		for (FacilityInfo scope : list) {
-			ArrayList<Object> a = new ArrayList<Object>();
-			a.add(scope.getFacilityId());
-			a.add(scope.getFacilityName());
-			a.add(scope.getDescription());
-			a.add(scope.getDisplaySortOrder());
-			listInput.add(a);
-		}
 		this.tableViewer.setInput(listInput);
 
 		// 件数表示
-		Object[] args = { String.valueOf(list.size()) };
+		Object[] args = { String.valueOf(listInput.size()) };
 		this.totalLabel.setText(Messages.getString("records", args));
 	}
 
