@@ -38,7 +38,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
  */
 public class ScopeListSelectionChangedListener implements ISelectionChangedListener {
 	/** リポジトリ[スコープ]ビュー用のコンポジット */
-	protected ScopeListComposite m_list;
+	private ScopeListComposite m_list;
 
 	/**
 	 * コンストラクタ
@@ -77,7 +77,7 @@ public class ScopeListSelectionChangedListener implements ISelectionChangedListe
 
 		//リポジトリ[スコープ]ビューのインスタンスを取得
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 		IViewPart viewPart = page.findView(ScopeListView.ID);
 
 		if(viewPart != null) {
@@ -103,7 +103,7 @@ public class ScopeListSelectionChangedListener implements ISelectionChangedListe
 				m_list.setSelectFacilityTreeItem(selectFacilityTreeItem);
 
 				//ビューのアクションの有効/無効を設定
-				view.setEnabledAction(selectFacilityTreeItem.getData().isBuiltInFlg(),selectFacilityTreeItem.getData().getFacilityType(), event.getSelection());
+				view.setEnabledAction(selectFacilityTreeItem.getData().isBuiltInFlg(),selectFacilityTreeItem.getData().getFacilityType(), event.getSelection(), selectFacilityTreeItem.getData().isNotReferFlg());
 			} else {
 				//選択ツリーアイテムを設定
 				m_list.setSelectFacilityTreeItem(null);
