@@ -29,7 +29,7 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.action.FacilityTree;
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.repository.composite.NodeFilterComposite;
@@ -45,6 +45,8 @@ import com.clustercontrol.ws.repository.InvalidRole_Exception;
  */
 public class NodeReleaseDialog extends CommonDialog {
 
+	private final int sizeY = 500;
+
 	// ----- instance フィールド ----- //
 
 	/** 割り当て対象スコープのファシリティID */
@@ -108,8 +110,7 @@ public class NodeReleaseDialog extends CommonDialog {
 		 */
 
 		// テーブル
-		this.nodeList = new NodeFilterComposite(parent, SWT.NONE,
-				this.facilityId);
+		this.nodeList = new NodeFilterComposite(parent, SWT.NONE, this.facilityId, false);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -132,6 +133,10 @@ public class NodeReleaseDialog extends CommonDialog {
 		Display display = shell.getDisplay();
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
+
+		//ダイアログのサイズ調整（pack:resize to be its preferred size）
+		shell.pack();
+		shell.setSize(new Point(shell.getSize().x, sizeY ));
 	}
 
 	/**
@@ -190,7 +195,7 @@ public class NodeReleaseDialog extends CommonDialog {
 
 		// 画面情報を取得
 		StructuredSelection selection = (StructuredSelection) this.nodeList
-		.getTableViewer().getSelection();
+				.getTableViewer().getSelection();
 
 		Object[] items = selection.toArray();
 		if (items != null) {
@@ -206,7 +211,7 @@ public class NodeReleaseDialog extends CommonDialog {
 			RepositoryEndpointWrapper.releaseNodeScope(facilityId, this.filterItems);
 
 			// リポジトリキャッシュの更新
-			FacilityTree.reflesh();
+			LocalSession.doCheck();
 
 			// 成功報告ダイアログを生成
 			MessageDialog.openInformation(
