@@ -10,6 +10,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.EndpointManager.EndpointSetting;
+import com.clustercontrol.ws.access.UsedOwnerRole_Exception;
 import com.clustercontrol.ws.repository.AgentStatusInfo;
 import com.clustercontrol.ws.repository.FacilityDuplicate_Exception;
 import com.clustercontrol.ws.repository.FacilityNotFound_Exception;
@@ -39,7 +40,7 @@ public class RepositoryEndpointWrapper {
 	private static Log m_log = LogFactory.getLog( RepositoryEndpointWrapper.class );
 
 	public static List<RepositoryTableInfo> getPlatformList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -55,7 +56,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void addNode(NodeInfo nodeInfo)
-	throws FacilityDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws FacilityDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -72,7 +73,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void addScope(String parentId, ScopeInfo scopeInfo)
-	throws FacilityDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws FacilityDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -89,7 +90,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void assignNodeScope(String scopeId, List<String> nodeId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -106,7 +107,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void deleteNode(String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, UsedFacility_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, UsedFacility_Exception, UsedOwnerRole_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -123,7 +124,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void deleteScope(String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, UsedFacility_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, UsedFacility_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -155,7 +156,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static NodeInfo getNode(String facilityId)
-	throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -171,7 +172,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static NodeInfo getNodePropertyBySNMP(String ipAddress, int port, String community, String version)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -187,7 +188,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<String> getNodeScopeList(String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -203,7 +204,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<FacilityInfo> getFacilityList(String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -219,7 +220,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static ScopeInfo getScope(String facilityId)
-	throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -235,7 +236,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void modifyNode(NodeInfo nodeInfo)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -252,7 +253,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void modifyScope(ScopeInfo scopeInfo)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -269,7 +270,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static void releaseNodeScope(String scopeId, List<String> nodeIdList)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -285,16 +286,16 @@ public class RepositoryEndpointWrapper {
 		throw wse;
 	}
 
-	public static List<RepositoryTableInfo> getVmSolutionMstList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public static List<RepositoryTableInfo> getCollectorSubPlatformTableInfoList()
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
 				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
-				return endpoint.getVmSolutionMstList();
+				return endpoint.getCollectorSubPlatformTableInfoList();
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getVmSolutionMstList(), " + e.getMessage(), e);
+				m_log.warn("getCollectorSubPlatformMstList(), " + e.getMessage(), e);
 				EndpointManager.changeEndpoint();
 			}
 		}
@@ -302,7 +303,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<String> getVmProtocolMstList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -318,7 +319,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<RepositoryTableInfo> getHostList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -350,7 +351,7 @@ public class RepositoryEndpointWrapper {
 
 
 	public static String getFacilityPath(String facilityId, String parentFacilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -366,7 +367,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<NodeInfo> getFilterNodeList(NodeInfo nodeInfo)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -382,7 +383,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<NodeInfo> getNodeList(String parentFacilityId, int level)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -398,7 +399,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<NodeInfo> getNodeListAll()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -414,7 +415,7 @@ public class RepositoryEndpointWrapper {
 	}
 
 	public static List<AgentStatusInfo> getAgentStatusList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -429,13 +430,13 @@ public class RepositoryEndpointWrapper {
 		throw wse;
 	}
 
-	public static FacilityTreeItem getFacilityTree()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public static FacilityTreeItem getFacilityTree(String ownerRoleId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
 				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
-				FacilityTreeItem item = endpoint.getFacilityTree();
+				FacilityTreeItem item = endpoint.getFacilityTree(ownerRoleId);
 				setTreeParent(item);
 				return item;
 			} catch (WebServiceException e) {
@@ -447,13 +448,13 @@ public class RepositoryEndpointWrapper {
 		throw wse;
 	}
 
-	public static FacilityTreeItem getExecTargetFacilityTreeByFacilityId(String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public static FacilityTreeItem getExecTargetFacilityTreeByFacilityId(String facilityId, String ownerRoleId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
 				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
-				FacilityTreeItem item = endpoint.getExecTargetFacilityTreeByFacilityId(facilityId);
+				FacilityTreeItem item = endpoint.getExecTargetFacilityTreeByFacilityId(facilityId, ownerRoleId);
 				if(item != null)
 					setTreeParent(item);
 				return item;
@@ -466,6 +467,25 @@ public class RepositoryEndpointWrapper {
 		throw wse;
 	}
 
+	public static FacilityTreeItem getNodeFacilityTree(String ownerRoleId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
+			try {
+				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
+				FacilityTreeItem item = endpoint.getNodeFacilityTree(ownerRoleId);
+				if(item != null)
+					setTreeParent(item);
+				return item;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getNodeFacilityTree(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
 	public static void setTreeParent(FacilityTreeItem item) {
 		List<FacilityTreeItem> children = item.getChildren();
 		for (FacilityTreeItem child : children) {
@@ -474,25 +494,8 @@ public class RepositoryEndpointWrapper {
 		}
 	}
 
-	public static void modifyAllNode(NodeInfo property, String parentFacilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
-		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
-			try {
-				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
-				endpoint.modifyAllNode(property, parentFacilityId);
-				return;
-			} catch (WebServiceException e) {
-				wse = e;
-				m_log.warn("modifyAllNode(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
-			}
-		}
-		throw wse;
-	}
-
 	public static void restartAgent(ArrayList<String> facilityIdList, int agentCommand)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
 			try {
@@ -507,4 +510,20 @@ public class RepositoryEndpointWrapper {
 		}
 		throw wse;
 	}
+
+	public static String replaceNodeVariable(String facilityId, String replaceObject)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getRepositoryEndpoint()) {
+			try {
+				RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting.getEndpoint();
+				return endpoint.replaceNodeVariable(facilityId, replaceObject);
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("replaceNodeVariable(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
 }
