@@ -15,11 +15,9 @@
 
 package com.clustercontrol.systemlog.factory;
 
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitorStringValueType;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * システムログ監視情報マネージャに登録するクラス<BR>
@@ -33,7 +31,7 @@ public class AddMonitorSystemlogString extends AddMonitorStringValueType{
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
 	@Override
-	protected boolean addCheckInfo() throws CreateException, NamingException{
+	protected boolean addCheckInfo() throws MonitorNotFound {
 
 		// システムログ監視のチェック条件はないため、常にtrue
 		return true;
@@ -51,7 +49,7 @@ public class AddMonitorSystemlogString extends AddMonitorStringValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_NONE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.NONE;
 	}
 }
