@@ -84,7 +84,7 @@ public class RequestWinRM {
 			String protocol,
 			int timeout,
 			int retries
-	) throws HinemosUnknown, WsmanException {
+			) throws HinemosUnknown, WsmanException {
 		m_log.debug("polling() " +
 				"ipAddress = " + ipAddress +
 				",user = " + user +
@@ -109,7 +109,8 @@ public class RequestWinRM {
 				m_url = protocol + "://" + ipAddress + ":" + port + "/wsman";
 			}
 		} catch (UnknownHostException e) {
-			m_log.warn("ipAddress is not valid : " + ipAddress);
+			m_log.info("polling() ipAddress is not valid : " + ipAddress
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw new HinemosUnknown("ipAddress is not valid : " + ipAddress);
 		}
 		m_log.debug("polling() url = " + m_url);
@@ -168,7 +169,7 @@ public class RequestWinRM {
 				}
 
 			} catch (WsmanException e) {
-				m_log.warn("polling()" + count + " " + e.getMessage() + ", " + e.getReason());
+				m_log.info("polling() " + count + " " + e.getMessage() + ", " + e.getReason());
 				m_log.debug("polling() ", e);
 
 				lastException = e; // 最後の例外を返却
@@ -195,7 +196,7 @@ public class RequestWinRM {
 			m_date = System.currentTimeMillis();
 
 			if(lastException != null){
-				m_log.warn("winservice message=" + lastException.getMessage() +
+				m_log.info("winservice message=" + lastException.getMessage() +
 						", reason=" + lastException.getReason());
 				if(lastException.getMessage() == null){
 					throw new HinemosUnknown(Messages.getString("message.winservice.3") + " : " + lastException.getReason());
